(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    114659,       3444]*)
(*NotebookOutlinePosition[    189135,       6001]*)
(*  CellTagsIndexPosition[    187248,       5947]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Dynamical Systems and Chaos "
}], "Title",
  CounterAssignments->{{"Title", 0}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "School of Physics, M013\nUniversity of Western Australia\n35 Stirling \
Highway\nCrawley WA 6009, Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The following options for ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ", ",
  StyleBox["DensityPlot", "InlineInputTraditionalForm"],
  ", and ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " are desirable."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ParametricPlot, 
        AspectRatio \[Rule] Automatic];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[DensityPlot, PlotPoints \[Rule] 100, 
        Mesh \[Rule] False, Compiled \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ListPlot, 
        PlotStyle \[Rule] AbsolutePointSize(0.002)];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Planar Pendulum"
}], "SectionFirst",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that is constrained by a rigid and massless rod to move in a vertical \
circle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ".  The equation of motion is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Omega]\^2\ \(sin(\[Theta](t))\) = 0, \ \[Omega] = 
      g\/l, \)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  StyleBox[" ",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "is the angle measured from the vertical direction with clockwise \
positive."
}], "Text"],

Cell[TextData[{
  "Usually, only the ",
  StyleBox["harmonic approximation",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\[Theta])\)]],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ") of this equation is considered:"
}], "Text",
  CellTags->"harmonic approximation"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Omega]\^2\ \(\[Theta](t)\) = 0. \)], "NumberedEquation"],

Cell[TextData[{
  "Here, the more general equation (which includes ",
  StyleBox["damping",
    FontSlant->"Italic"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  \[NotEqual] \ 0\)]],
  " and a ",
  StyleBox["sinusoidal driving term",
    FontSlant->"Italic"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  \[NotEqual] \ 0\)]],
  ")"
}], "Text",
  CellTags->{"damping", "sinusoidal driving term"}],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Beta]\ \(\(\[Theta]\& . \)(
            t)\) + \[Omega]\^2\ \(sin(\[Theta](
              t))\) = \[Alpha]\ \(sin(\[Omega]\_d\ t)\)\)], "NumberedEquation"],

Cell[TextData[{
  "will be examined. The units of mass, length, and time are chosen so that \
they are all equal to unity, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", we are working with ",
  StyleBox["dimensionless variables",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Undamped pendulum"
}], "Subsection"],

Cell[TextData[{
  "The dimensionless equation for the undamped pendulum in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation reads"
}], "Text",
  CellTags->"undamped pendulum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], 
              "+", \(sin(\[Theta](t))\)}], "==", "0"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  " to numerically solve ",
  StyleBox["\[ScriptCapitalP]", "InlineInputTraditionalForm"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " for 10 units of time (\"seconds\") with the initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) == 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^\[Prime]\)(0) \[Equal] 1\)]],
  " and call the result ",
  StyleBox["\[ScriptU]", "InlineInputTraditionalForm"],
  ". (NB. It is more convenient to solve for \[Theta] rather than ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)]],
  "). Display a ",
  StyleBox["phase-space plot",
    FontSlant->"Italic"],
  " by pairing up the angle and angular velocity values using ",
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(\[Theta](t)\), ",", 
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}]}], "}"}], "/.", 
          "\[InvisibleSpace]", \(First[\[ScriptU]]\)}], TraditionalForm]], 
    "InlineInputTraditionalForm"], "InlineInputTraditionalForm"],
  " and visualize the motion using ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ". Describe the trajectory that results. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"phase-space plot"],

Cell[CellGroupData[{

Cell[" Answer", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"u", "=", 
        RowBox[{"NDSolve", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{\(sin(\[Theta](t))\), "+", 
                    RowBox[{
                      SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                        MultilineFunction->None], "(", "t", ")"}]}], 
                  "\[LongEqual]", "0"}], ",", \(\[Theta](0) \[LongEqual] 0\), 
                ",", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]",
                      MultilineFunction->None], "(", "0", ")"}], 
                  "\[LongEqual]", "1"}]}], "}"}], ",", "\[Theta]", 
            ",", \({t, 0, 10}\)}], "]"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{"\[Theta]", "\[Rule]", 
            TagBox[
              RowBox[{"InterpolatingFunction", "[", 
                RowBox[{
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {"0.`", "10.`"}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
                  ",", "\<\"<>\"\>"}], "]"}],
              False,
              Editable->False]}], "}"}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"ParametricPlot", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"{", 
              RowBox[{\(\[Theta](t)\), ",", 
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}]}], "}"}], "/.", 
            "\[InvisibleSpace]", \(First[u]\)}], ",", \({t, 0, 10}\)}], "]"}],
       TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95493 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9  scalefont  setfont
% Scaling calculations
0.499998 0.45473 0.47746 0.45473 [
[.04527 .46496 -7.9375 -13.25 ]
[.04527 .46496 7.9375 0 ]
[.27263 .46496 -11.6875 -13.25 ]
[.27263 .46496 11.6875 0 ]
[.72736 .46496 -8.25 -13.25 ]
[.72736 .46496 8.25 0 ]
[.95473 .46496 -4.5 -13.25 ]
[.95473 .46496 4.5 0 ]
[.4875 .02273 -15.875 -6.625 ]
[.4875 .02273 0 6.625 ]
[.4875 .25009 -23.375 -6.625 ]
[.4875 .25009 0 6.625 ]
[.4875 .70483 -16.5 -6.625 ]
[.4875 .70483 0 6.625 ]
[.4875 .93219 -9 -6.625 ]
[.4875 .93219 0 6.625 ]
[ 0 0 0 0 ]
[ 1 .95493 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .47746 m
.04527 .48371 L
s
gsave
.04527 .46496 -68.9375 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27263 .47746 m
.27263 .48371 L
s
gsave
.27263 .46496 -72.6875 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.72736 .47746 m
.72736 .48371 L
s
gsave
.72736 .46496 -69.25 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.95473 .47746 m
.95473 .48371 L
s
gsave
.95473 .46496 -65.5 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.09074 .47746 m
.09074 .48121 L
s
.13621 .47746 m
.13621 .48121 L
s
.18169 .47746 m
.18169 .48121 L
s
.22716 .47746 m
.22716 .48121 L
s
.31811 .47746 m
.31811 .48121 L
s
.36358 .47746 m
.36358 .48121 L
s
.40905 .47746 m
.40905 .48121 L
s
.45453 .47746 m
.45453 .48121 L
s
.54547 .47746 m
.54547 .48121 L
s
.59094 .47746 m
.59094 .48121 L
s
.63642 .47746 m
.63642 .48121 L
s
.68189 .47746 m
.68189 .48121 L
s
.77284 .47746 m
.77284 .48121 L
s
.81831 .47746 m
.81831 .48121 L
s
.86378 .47746 m
.86378 .48121 L
s
.90926 .47746 m
.90926 .48121 L
s
.25 Mabswid
0 .47746 m
1 .47746 L
s
.5 .02273 m
.50625 .02273 L
s
gsave
.4875 .02273 -76.875 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .25009 m
.50625 .25009 L
s
gsave
.4875 .25009 -84.375 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .70483 m
.50625 .70483 L
s
gsave
.4875 .70483 -77.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .93219 m
.50625 .93219 L
s
gsave
.4875 .93219 -70 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .0682 m
.50375 .0682 L
s
.5 .11368 m
.50375 .11368 L
s
.5 .15915 m
.50375 .15915 L
s
.5 .20462 m
.50375 .20462 L
s
.5 .29557 m
.50375 .29557 L
s
.5 .34104 m
.50375 .34104 L
s
.5 .38651 m
.50375 .38651 L
s
.5 .43199 m
.50375 .43199 L
s
.5 .52293 m
.50375 .52293 L
s
.5 .56841 m
.50375 .56841 L
s
.5 .61388 m
.50375 .61388 L
s
.5 .65935 m
.50375 .65935 L
s
.5 .7503 m
.50375 .7503 L
s
.5 .79577 m
.50375 .79577 L
s
.5 .84124 m
.50375 .84124 L
s
.5 .88672 m
.50375 .88672 L
s
.25 Mabswid
.5 0 m
.5 .95493 L
s
0 0 m
1 0 L
1 .95493 L
0 .95493 L
closepath
clip
newpath
.5 Mabswid
.5 .93219 m
.50561 .93216 L
.51072 .93206 L
.51661 .93189 L
.52218 .93165 L
.53207 .93106 L
.54279 .93017 L
.55457 .92891 L
.56702 .92723 L
.58922 .92338 L
.6119 .91828 L
.63289 .91248 L
.67949 .89576 L
.72488 .87398 L
.76408 .85026 L
.80656 .8185 L
.84242 .78563 L
.8974 .71965 L
.92094 .68212 L
.9416 .64062 L
.95701 .59959 L
.96373 .57612 L
.96865 .55436 L
.97195 .53517 L
.97341 .52424 L
.97449 .51402 L
.97497 .50848 L
.97535 .50322 L
.97563 .49845 L
.97587 .49337 L
.97597 .49075 L
.97605 .48785 L
.97616 .48275 L
.97618 .47989 L
.97619 .47679 L
.97617 .47388 L
.97614 .4712 L
.97602 .46592 L
.97584 .46094 L
.97563 .45646 L
.97534 .45161 L
.97448 .44074 L
.97341 .43072 L
.97081 .4125 L
.96714 .39328 L
.95635 .35327 L
.94839 .33083 L
.93975 .3101 L
.91924 .26982 L
.89578 .23296 L
Mistroke
.84182 .16869 L
.80911 .13856 L
.77111 .10945 L
.73281 .08535 L
.69563 .06625 L
.65008 .04797 L
.6254 .04025 L
.59894 .03358 L
.57559 .02904 L
.55364 .0259 L
.54097 .02458 L
.52941 .02368 L
.523 .02331 L
.51962 .02315 L
.51604 .02301 L
.51291 .02291 L
.50945 .02283 L
.50337 .02274 L
.49754 .02274 L
.49212 .0228 L
.48617 .02294 L
.48284 .02305 L
.47983 .02318 L
.47371 .02349 L
.4671 .02392 L
.45513 .02495 L
.444 .02619 L
.43227 .02779 L
.41138 .03142 L
.38744 .03681 L
.36537 .04296 L
.3165 .06085 L
.27201 .08264 L
.23224 .10714 L
.16526 .1617 L
.13491 .19374 L
.10632 .23 L
.06512 .29957 L
.04946 .33652 L
.04269 .35624 L
.03667 .37721 L
.03233 .39576 L
.02859 .41618 L
.02728 .42518 L
.02612 .43482 L
.02531 .4431 L
.02462 .45222 L
.0243 .45773 L
.02408 .46289 L
.02391 .46834 L
Mistroke
.02385 .4714 L
.02382 .4742 L
.02381 .47918 L
.02387 .48461 L
.024 .48973 L
.02417 .49449 L
.02448 .50049 L
.02485 .50613 L
.02576 .51667 L
.02706 .52801 L
.02883 .54024 L
.03275 .56115 L
.03811 .58311 L
.05079 .62194 L
.06705 .65932 L
.08855 .69821 L
.1375 .76415 L
.16998 .79771 L
.20918 .83108 L
.24603 .85685 L
.28949 .8815 L
.33389 .90113 L
.37726 .91542 L
.40171 .92148 L
.42437 .92587 L
.43736 .92786 L
.44948 .92938 L
.46217 .93061 L
.46889 .93113 L
.47607 .93156 L
.48196 .93183 L
.48534 .93195 L
.48844 .93204 L
.4917 .93211 L
.4952 .93217 L
.49845 .93219 L
.50153 .93219 L
.50736 .93213 L
.51277 .93201 L
.51869 .93181 L
.525 .9315 L
.53188 .93107 L
.53931 .93049 L
.55273 .92913 L
.56576 .92742 L
.57767 .92552 L
.62333 .91525 L
.64585 .90838 L
.67008 .89958 L
.75274 .85763 L
Mistroke
.79482 .82798 L
.82997 .79776 L
.88794 .73278 L
.91466 .69292 L
.93524 .65459 L
.95128 .61639 L
.96276 .57988 L
.96776 .55874 L
.97132 .53928 L
.97288 .5285 L
.97423 .51672 L
.97473 .51132 L
.97519 .50557 L
.97553 .50021 L
.97579 .4952 L
.97599 .49008 L
.97607 .48736 L
.97613 .48445 L
.97617 .48139 L
.97619 .4785 L
.97617 .47307 L
.97608 .46801 L
.97594 .46332 L
.97572 .45818 L
.97541 .45271 L
.97454 .44146 L
.97343 .4309 L
.97189 .41934 L
.96984 .4069 L
.96548 .38595 L
.95968 .36403 L
.94622 .32534 L
.9291 .28795 L
.90674 .24924 L
.85633 .1839 L
.82297 .15068 L
.78294 .11791 L
.74543 .09276 L
.70143 .06897 L
.66791 .05449 L
.63071 .04179 L
.60976 .03611 L
.59038 .03177 L
.55195 .0257 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 275},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Eb000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00Y`3oool0103o`g/0000000000000Nl<80?ooo`030000003oool0oooo0;80oooo002X
0?ooo`030>6QCP00Nl<0oooo00P0oooo00<000000?ooo`3oool0/P3oool00:P0oooo00<0hJ5>001k
``3oool0203oool00`000000oooo0?ooo`2b0?ooo`00W@3oool00`3ohJ40CP000000000400000003
04jQh@3oool0000001T00000Z03oool009h0oooo200000020?ooo`030>6QCP00Nl<0oooo00P0oooo
00<000000?ooo`3oool02P3oool:000009h0oooo002H0?ooo`H000002P3oool00`3QXDh007_30?oo
o`080?ooo`030000003oool0oooo01@0oooo1P00002H0?ooo`00TP3oool600000100oooo00<0hJ5>
001k``3oool0203oool00`000000oooo0?ooo`0J0?ooo`D00000T`3oool008h0oooo1000000E0?oo
o`030>6QCP00000007_300T0oooo00<000000?ooo`3oool07P3oool5000008l0oooo002:0?ooo`@0
00006P3oool00`3QXDh007_30?ooo`080?ooo`030000003oool0oooo02<0oooo1@00002:0?ooo`00
QP3oool4000002T0oooo00<000000?ooo`3oool09P3oool6000008H0oooo00220?ooo`@00000;@3o
ool00`000000oooo0?ooo`0Z0?ooo`D00000P`3oool00800oooo0P00000a0?ooo`030000003oool0
oooo02h0oooo100000200?ooo`00O@3oool3000003<0oooo00<000000?ooo`3oool0<@3oool40000
07d0oooo001k0?ooo`800000=P3oool00`000000oooo0?ooo`0e0?ooo`<00000NP3oool007P0oooo
0`00000h0?ooo`030000003oool0oooo03L0oooo0`00001h0?ooo`00M@3oool3000003/0oooo00<0
00000?ooo`3oool0>@3oool3000007H0oooo001c0?ooo`800000?P3oool00`000000oooo0?ooo`0k
0?ooo`<00000M03oool00740oooo0P0000100?ooo`030000003oool0oooo03h0oooo0P00001b0?oo
o`00K`3oool200000480oooo00<000000?ooo`3oool0@03oool200000700oooo001]0?ooo`800000
A03oool2000004<0oooo0`00001]0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0A03o
ool3000006/0oooo001Y0?ooo`800000B03oool00`000000oooo0?ooo`160?ooo`<00000J@3oool0
06L0oooo0P00001:0?ooo`030000003oool0oooo04P0oooo1000001V0?ooo`00I@3oool2000004`0
oooo00<000000?ooo`3oool0BP3oool4000006@0oooo001S0?ooo`800000CP3oool00`000000oooo
0?ooo`1<0?ooo`@00000HP3oool00640oooo0P00001@0?ooo`030000003oool0oooo04h0oooo1000
001P0?ooo`00G`3oool200000580oooo00<000000?ooo`3oool0D03oool4000005h0oooo001M0?oo
o`800000E03oool00`000000oooo0?ooo`1B0?ooo`<00000G@3oool005/0oooo0P00001F0?ooo`03
0000003oool0oooo05@0oooo0`00001K0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo05H0oooo0P00001J0?ooo`00F03oool2000005T0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1G0?ooo`00EP3oool2000005/0oooo00<000000?ooo`3oool0F@3oool2
000005L0oooo001D0?ooo`800000G@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
05@0oooo001C0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0G03oool2000005@0
oooo001B0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0G@3oool2000005<0oooo
001A0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`1@0?ooo`00C`3oool200000680oooo0P00001Q0?ooo`800000D03oool004h0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04d0oooo001=0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1<0?ooo`00
C03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo0P00001<0?ooo`00B`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo0P00001;0?ooo`00B@3oool2
000006P0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`180?ooo`00B03oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0A`3oool004L0
oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`800000A`3oool004H0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04@0oooo
00150?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`130?ooo`00@`3oool2000006h0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`12
0?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo0P0000120?oo
o`00@@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo0P0000110?ooo`00
@03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
?P3oool003l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo03d0oooo000m0?ooo`800000M03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo03`0oooo000l0?ooo`030000003oool0oooo07@0oooo0P00001e0?ooo`030000003oool0oooo
03/0oooo000k0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0M@3oool2000003/0
oooo000j0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3oool2000003X0oooo
000i0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0M`3oool2000003T0oooo000h
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0N03oool2000003P0oooo000g0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0N@3oool2000003L0oooo000f0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0e0?ooo`00
=@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
=03oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo03<0oooo000c0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00;`3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool002h0oooo00<00000
0?ooo`3oool0PP3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo02h0oooo000^0?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0]0?oo
o`00;@3oool00`000000oooo0?ooo`230?ooo`800000P`3oool2000002h0oooo000/0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0P`3oool2000002d0oooo000[0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0[0?ooo`00:`3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0:P3oool0
02X0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
02T0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0QP3oool2000002X0
oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0Q`3oool2000002T0oooo
000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool2000002P0oooo000W
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0V
0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool09@3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`80
00009P3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2;0?ooo`800000
9@3oool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02<0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`1g0?ooo`090?oQX@1>0000001>
0:7Qo`3oool0on6Q04h0001k`ol0ol=k0080000000<007_30?ooo`3oool0203oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo07L0oooo00H0
ooo307/0CP2QhOl0on6Q04i>X@3Qool60?ooo`030?o3N`1>XN40oooo00P0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0Q0?ooo`008P3oool00`000000oooo0?ooo`1g0?ooo`060?o3
N`00Nl<0oooo0?ooh@2QCP00Nl?o1P3oool00`3oon40XDik0<?oo`080?ooo`030000003oool0oooo
08h0oooo0P00000R0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`030?oQX@1>0000000000@0
000000<0CZ7Q0>6QCP1>XN400P3oool00`33N`00CZ7Q0?ooo`060?ooo`030<=kN`33ool0oooo00L0
oooo0`00002?0?ooo`8000008@3oool00240oooo00<000000?ooo`3oool0N03oool01P3QXDh0CZ7Q
0?ooo`3oool0`g/004jQh@H0oooo00<0ooo307/0N`33ool0203oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo07T0oooo00H0hJ5>001k``3o
ool0oooo0<=k001>XN450?ooo`030?oQX@1>0000CZ7Q00T0oooo00<000000?ooo`3oool0T03oool2
00000200oooo000O0?ooo`030000003oool0oooo07X0oooo00H0ol=k001k``3oool0oooQ0:5>001k
`ol30?ooo`040?oo``1k0000000004jQh@X0oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`1j0?ooo`060?oo``1k04h0XN7o0?oQX@1>07/0
`ooo103oool00`3QXG/0XN7o0?ooo`0:0?ooo`030000003oool0oooo0940oooo0P00000O0?ooo`00
7P3oool00`000000oooo0?ooo`1l0?ooo`040?oQX@1>0000001>0:7Qo`D0oooo00D0ooo307/00000
0000001k0<?oo`080?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool07@3oool001h0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2B0?ooo`8000007P3oool001d0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2C0?ooo`8000007@3oool001`0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo000L
0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0U03oool2000001`0oooo000K0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0J0?oo
o`006`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo09D0oooo0P00000K0?ooo`00
6P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
6@3oool001T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`2F0?ooo`8000006P3o
ool001T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo01P0oooo000H0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0V03oool00`00
0000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`2H0?ooo`800000V@3oool00`000000
oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool05P3oool001L0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo01H0oooo000F0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0VP3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`2J0?ooo`8000005P3oool001D0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003o
ool0oooo09`0oooo00<000000?ooo`3oool0V`3oool2000001D0oooo000D0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0C0?ooo`00503oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool04`3oool001<0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0180
oooo000C0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0B0?ooo`004P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09d0oooo0P00
000C0?ooo`004P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool04@3oool00140oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo0140oooo000A0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`2O0?ooo`800000
X03oool00`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0403oool00100oooo00<000000?ooo`3oool0X03oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000
oooo0?ooo`2P0?ooo`030000003oool0oooo0:00oooo0P00000@0?ooo`003`3oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool03P3oool000l0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00h0oooo000?
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0=
0?ooo`003P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool03@3oool000h0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`2S0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo0:<0oooo0P00000=0?ooo`00303oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool02`3oool000`0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00/0oooo000<
0?ooo`030000003oool0oooo0:@0oooo0P00002U0?ooo`030000003oool0oooo00/0oooo000<0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0Y03oool2000000`0oooo000;0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0:0?ooo`00
2`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
2P3oool000/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00X0oooo000;0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0Y@3oool0
0`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`090?oo
o`002@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool02@3oool000T0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2V0?ooo`800000
2P3oool000T0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo00P0oooo00090?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`060?ooo`040?o3N`0000000000
001k`dT0oooo00T0on6Q04h0000004h0XN7o0?ooo`3ohJ40CP0007_3o`3o`g/00P0000000`00Nl<0
oooo0?ooo`160?ooo`800000B@3oool02@3ohJ40CP000000CP2QhOl0oooo0?oQX@1>0000Nl?o0?o3
N`0200000003001k``3oool0oooo04P0oooo00@0ol=k00000000000007_31@3oool00`000000oooo
0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`070?ooo`030>6QCP00Nl<0oooo04P0oooo00H0
ooo307/0CP2QhOl0on6Q04i>X@3Qool60?ooo`030?o3N`1>XN40oooo04H0oooo00<000000?ooo`3o
ool0A`3oool01P3ool<0N`1>0:7Qo`3ohJ40CTjQ0>7oo`H0oooo00<0ol=k04jQh@3oool0B@3oool0
0`3QXDh007_30?ooo`050?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo
00L0oooo00<0hJ5>001k``3oool0B03oool01P3o`g/007_30?ooo`3oon40XDh007_3o`H0oooo00<0
oooQ0:5>N`33ool0AP3oool00`000000oooo0?ooo`170?ooo`060?o3N`00Nl<0oooo0?ooh@2QCP00
Nl?o1P3oool00`3oon40XDik0<?oo`190?ooo`030>6QCP00Nl<0oooo00D0oooo00<000000?ooo`3o
ool0203oool000T0oooo00<0000004h000000000100000001@1>XN40oooo0?ooo`3QXDh007_30400
oooo00<0on6Q04h00000000010000000101>XN40oooo0>6QCP1>XN420?ooo`030<=k001>XN40oooo
00H0oooo00<0`g]k0<?oo`3oool0A@3oool00`000000oooo0?ooo`170?ooo`060>6QCP1>XN40oooo
0?ooo`33N`00CZ7Q1`3oool00`33Ng/0`ooo0?ooo`180?ooo`030>6QCP00Nl<0oooo00D0oooo00<0
00000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool01`3oool00`3QXDh007_30?ooo`18
0?ooo`060>6QCP1>XN40oooo0?ooo`33N`00CZ7Q1P3oool00`3ool<0N`1k0<?oo`160?ooo`030000
003oool0oooo04L0oooo00H0hJ5>04jQh@3oool0oooo0<=k001>XN460?ooo`030?oo``1k07/0`ooo
04T0oooo00<0hJ5>001k``3oool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000
oooo0?ooo`070?ooo`030>6QCP00Nl<0oooo04P0oooo00H0hJ5>001k``3oool0oooo0<=k001>XN45
0?ooo`030?oQX@1>0000CZ7Q04L0oooo00<000000?ooo`3oool0A`3oool01P3QXDh007_30?ooo`3o
ool0`g/004jQh@D0oooo00<0on6Q04h0001>XN40BP3oool00`3QXDh007_30?ooo`050?ooo`030000
003oool0oooo00P0oooo00090?ooo`030000003oool0oooo00L0oooo00<0hJ5>001k``3oool0B03o
ool01P3o`g/007_30?ooo`3oon40XDh007_3o`<0oooo00@0ooo307/000000000CZ7QB03oool00`00
0000oooo0?ooo`170?ooo`060?o3N`00Nl<0oooo0?ooh@2QCP00Nl?o0`3oool0103ool<0N`000000
001>XN5;0?ooo`030>6QCP00Nl<0oooo00D0oooo0P0000090?ooo`002@3oool00`000000oooo0?oo
o`060?ooo`030>6QCP00000007_304T0oooo00H0ooo307/0CP2QhOl0on6Q04h0N`33ool40?ooo`03
0>6QN`2QhOl0oooo04P0oooo00<000000?ooo`3oool0A`3oool01P3ool<0N`1>0:7Qo`3ohJ40CP1k
0<?oo`@0oooo00<0hJ5k0:7Qo`3oool0BP3oool00`3QXDh00000001k``060?ooo`8000002@3oool0
00P0oooo00<000000?ooo`3oool0203oool00`3QXDh007_30?ooo`190?ooo`040?oQX@1>0000001>
0:7Qo`D0oooo00D0ooo307/000000000001k0<?oo`160?ooo`030000003oool0oooo04P0oooo00@0
on6Q04h0000004h0XN7o1@3oool01@3ool<0N`000000000007/0`ooo04T0oooo00<0hJ5>001k``3o
ool01@3oool2000000T0oooo00080?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`070?ooo`00203oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`070?ooo`00o`00001X00000040oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`2W0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000
003oool0oooo0:L0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`080?ooo`002@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0203o
ool000T0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo00P0oooo00090?ooo`030000003oool0oooo0:L0oooo0P00002X0?ooo`030000003oool0oooo
00P0oooo00090?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`2V0?ooo`8000002P3oool000T0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0YP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0:D0oooo0P00000;0?ooo`002P3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool02P3oool000/0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00X0
oooo000;0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2T
0?ooo`800000303oool000/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo00/0oooo000;0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`2T0?ooo`800000
Y@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo0:<0oooo0P00000=0?ooo`00303oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0303oool000`0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`2S0?ooo`030000003oool0oooo0:80oooo0P00000>0?ooo`003@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool03@3oool000h0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00d0oooo000>0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0=0?oo
o`003P3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool03P3oool000l0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0X03oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo09l0oooo0P00000A0?ooo`004@3oool00`000000oooo0?oo
o`2O0?ooo`800000X03oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0403oool00180oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`2N0?ooo`8000004P3oool00180oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0W@3oool2000001<0oooo000C0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool04P3oool0
01@0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
01<0oooo000D0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo09/0oooo
0P00000E0?ooo`005@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0503oool001H0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo01@0oooo000F0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01H0oooo000H0?ooo`030000003o
ool0oooo09P0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0F0?ooo`00603oool0
0`000000oooo0?ooo`2H0?ooo`800000V@3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool05`3oool001T0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01P0
oooo000I0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`0H0?ooo`006P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool06P3oool001`0oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo000L0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0K0?ooo`007@3oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0703oool0
01d0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
01`0oooo000N0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0940oooo
0P00000O0?ooo`007`3oool00`000000oooo0?ooo`1k0?ooo`090?oQX@1>0000001>0:7Qo`3oool0
on6Q04h0001k`ol0ol=k0080000000<007_30?ooo`3oool0203oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo01h0oooo000P0?ooo`030000003oool0oooo07T0oooo00H0ooo307/0CP2Q
hOl0on6Q04i>X@3Qool60?ooo`030?o3N`1>XN40oooo00P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`1i0?ooo`060?o3N`00Nl<0oooo
0?ooh@2QCP00Nl?o1P3oool00`3oon40XDik0<?oo`080?ooo`030000003oool0oooo08l0oooo0P00
000Q0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`060>6QCP1>XN40oooo0?ooo`33N`00CZ7Q
1`3oool00`33Ng/0`ooo0?ooo`070?ooo`<00000S`3oool00`000000oooo0?ooo`0P0?ooo`008P3o
ool00`000000oooo0?ooo`1g0?ooo`060>6QCP1>XN40oooo0?ooo`33N`00CZ7Q1P3oool00`3ool<0
N`1k0<?oo`080?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08@3oool002<0oooo
00<000000?ooo`3oool0MP3oool01P3QXDh007_30?ooo`3oool0`g/004jQh@D0oooo00<0on6Q04h0
001>XN402@3oool00`000000oooo0?ooo`2=0?ooo`8000008`3oool002<0oooo00<000000?ooo`3o
ool0MP3oool01P3o`g/007_30?ooo`3oon40XDh007_3o`<0oooo00@0ooo307/000000000CZ7Q2P3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo000T0?ooo`030000003oool0
oooo07D0oooo00H0ooo307/0CP2QhOl0on6Q04h0N`33ool40?ooo`030>6QN`2QhOl0oooo00X0oooo
00<000000?ooo`3oool0S03oool2000002@0oooo000U0?ooo`030000003oool0oooo07D0oooo00@0
on6Q04h0000004h0XN7o1@3oool01@3ool<0N`000000000007/0`ooo00P0oooo00<000000?ooo`3o
ool0R`3oool2000002D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool09@3oool002L0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo000X0?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0V0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0Y0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0P`3oool2000002d0oooo000]0?ooo`030000003oool0oooo08<0oooo0P0000240?ooo`030000
003oool0oooo02`0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`0]0?ooo`00;`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<@3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo07h0oooo0P00000b0?ooo`00<P3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo07d0oooo0P00000c0?ooo`00<`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo07`0oooo0P00000d0?ooo`00=03oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo07/0oooo0P00000e0?ooo`00=@3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo07X0oooo0P00000f0?ooo`00=P3oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo07T0oooo0P00000g0?ooo`00=`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`000000=`3oool003P0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`1h0?ooo`800000>03oool003T0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`1g0?ooo`800000>@3oool003X0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`1f0?ooo`800000>P3oool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`1e0?ooo`800000>`3oool003`0oooo00<000000?ooo`3oool0M03oool2000007D0oooo0P00
000l0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0?03oool003h0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo03d0oooo000o0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool200000740oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`0o0?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo0P0000120?ooo`00@`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo06d0oooo0P0000130?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
06`0oooo0P0000140?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool0A03oool004H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo00170?ooo`800000JP3oool00`000000oooo0?oo
o`1X0?ooo`800000B03oool004T0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1W
0?ooo`800000B@3oool004X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1V0?oo
o`800000BP3oool004/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`80
0000B`3oool004`0oooo0P00001U0?ooo`030000003oool0oooo06<0oooo0P00001=0?ooo`00CP3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0680oooo0P00001>0?ooo`00C`3oool2
00000680oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>0?ooo`00D@3oool00`00
0000oooo0?ooo`1O0?ooo`800000H03oool200000540oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool200000580oooo001C0?ooo`800000GP3oool00`000000oooo
0?ooo`1L0?ooo`800000E03oool005D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`1K0?ooo`800000E@3oool005H0oooo0P00001K0?ooo`030000003oool0oooo05T0oooo0`00001F
0?ooo`00F03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo0P00001H0?oo
o`00F@3oool2000005P0oooo00<000000?ooo`3oool0EP3oool2000005X0oooo001K0?ooo`800000
EP3oool00`000000oooo0?ooo`1D0?ooo`800000G03oool005d0oooo0P00001D0?ooo`030000003o
ool0oooo0580oooo0`00001M0?ooo`00G`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0500oooo0`00001O0?ooo`00H03oool200000540oooo00<000000?ooo`3oool0CP3oool30000
0640oooo001R0?ooo`800000C`3oool00`000000oooo0?ooo`1<0?ooo`<00000H`3oool006@0oooo
0P00001=0?ooo`030000003oool0oooo04X0oooo0`00001U0?ooo`00IP3oool2000004/0oooo00<0
00000?ooo`3oool0B@3oool2000006L0oooo001X0?ooo`800000B@3oool00`000000oooo0?ooo`17
0?ooo`800000J@3oool006X0oooo0P0000170?ooo`030000003oool0oooo04D0oooo0P00001[0?oo
o`00K03oool2000004D0oooo0P0000140?ooo`800000K@3oool006h0oooo0P0000130?ooo`030000
003oool0oooo0440oooo0P00001_0?ooo`00L03oool200000440oooo00<000000?ooo`3oool0?`3o
ool200000740oooo001b0?ooo`800000?`3oool00`000000oooo0?ooo`0l0?ooo`<00000L`3oool0
07@0oooo0P00000m0?ooo`030000003oool0oooo03X0oooo0`00001e0?ooo`00MP3oool3000003X0
oooo00<000000?ooo`3oool0=`3oool4000007L0oooo001i0?ooo`<00000=`3oool00`000000oooo
0?ooo`0d0?ooo`D00000N@3oool007`0oooo0`00000d0?ooo`030000003oool0oooo0380oooo1000
001l0?ooo`00O`3oool400000300oooo00<000000?ooo`3oool0;`3oool4000007l0oooo00230?oo
o`<00000;@3oool00`000000oooo0?ooo`0/0?ooo`@00000PP3oool008H0oooo1000000Y0?ooo`03
0000003oool0oooo02P0oooo100000260?ooo`00RP3oool4000002D0oooo00<000000?ooo`3oool0
903oool4000008X0oooo002>0?ooo`@000008@3oool00`000000oooo0?ooo`0P0?ooo`@00000SP3o
ool00980oooo1000000A0?ooo`040?o3N`0000000000001k``P0oooo00<000000?ooo`3oool06P3o
ool600000980oooo002F0?ooo`D000003@3oool00`3QXDh007_30?ooo`080?ooo`030000003oool0
oooo01@0oooo2000002F0?ooo`00V`3oool8000000D0oooo00<0hJ5>001k``3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`d00000VP3oool00:<0oooo8@00002T0?ooo`00Z03oool00`3QXDh007_3
0?ooo`080?ooo`030000003oool0oooo0;80oooo002X0?ooo`030>6QCP00Nl<0oooo00P0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0hJ5>001k``3oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Y`3oool00`3QXDh00000001k``090?ooo`030000003oool0oooo0;80oooo002X0?ooo`03
0>6QCP00Nl<0oooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {342.75, 0}} -> {-1.1006, -1.05079, \
0.00766438, 0.00766438}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that we are using the first (in this case there is only one) \
numerical solution to the differential equation and computing its derivative \
(",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}], TraditionalForm]]],
  ") ",
  StyleBox["numerically",
    FontSlant->"Italic"],
  "."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Increase the initial velocity, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", to something slightly less than 2 and redo ",
  
  CounterBox["Exercise", "phase-space plot"],
  ". Explain what is happening here. ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Set ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " to 2 and redo ",
  
  CounterBox["Exercise", "phase-space plot"],
  ", but over a longer time interval. Explain what is happening here. ",
  StyleBox["[2 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Explain the critical value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " from an energy viewpoint (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": the kinetic energy is proportional to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\/2\), " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}], "2"]}], 
        TraditionalForm]]],
  " and the initial potential energy is 0. What is the total energy at the \
top of the loop?). ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Damped pendulum"
}], "Subsection"],

Cell[TextData[{
  "The equation for the ",
  StyleBox["damped pendulum",
    FontSlant->"Italic"],
  " (where the damping is proportional to the velocity) can be written"
}], "Text",
  CellTags->"damped pendulum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "+", 
              RowBox[{"\[Beta]", " ", 
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}]}], 
              "+", \(sin(\[Theta](t))\)}], "==", "0"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the equation numerically for the damped pendulum with damping ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[Beta] \[Rule] 0.2\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) == 0\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "(", "0", ")"}], "==", "1"}], 
        TraditionalForm]]],
  " for 20 seconds. Display a phase-space plot and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Damped driven pendulum"
}], "Subsection"],

Cell[TextData[{
  "The equation for the ",
  StyleBox["damped driven pendulum",
    FontSlant->"Italic"],
  " can be written"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "+", 
              RowBox[{"\[Beta]", " ", 
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}]}], 
              "+", \(sin(\[Theta](t))\)}], 
            "==", \(\[Alpha]\ \(cos(\[Omega]\ t)\)\)}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the equation numerically for the damped driven pendulum with ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Beta] \[Rule] 0.2, \[Alpha] \[Rule] 
          0.52, \[Omega] \[Rule] 0.694}\)]],
  " and initial conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{\(\[Theta](0) == 0.8\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], "\[Equal]", 
              "0.8"}]}], "}"}], TraditionalForm]]],
  " for 400 seconds and call the result ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  ". You will need to increase the number of time-steps by playing with the \
",
  StyleBox["MaxSteps", "InlineInputTraditionalForm"],
  " option of ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  ". Display a phase-space plot of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{\(\[Theta](t)\), ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " using ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  " with ",
  StyleBox["AspectRatio \[Rule] 1/4", "InlineInputTraditionalForm"],
  " and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Physically, since the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \[Element] \([\(-\[Pi]\), \[Pi]]\)\)]],
  ", it makes more sense to examine ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[\(\((\[Theta] - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
          Mod[ 
            Plus[ 
              \[Theta][ t], 
              Times[ -1, Pi]], 
            Times[ 2, Pi]]], TraditionalForm]]],
  ". Display a phase-space plot of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            
            InterpretationBox[\(\((\[Theta](
                      t) - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
              Mod[ 
                Plus[ 
                  \[Theta][ t], 
                  Times[ -1, Pi]], 
                Times[ 2, Pi]]], ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "You should see that the resulting phase-space diagram is ",
  StyleBox["periodic",
    FontSlant->"Italic"],
  " (in the language of chaos it shows a ",
  StyleBox["period-3 limit cycle",
    FontSlant->"Italic"],
  ")."
}], "Text",
  CellTags->{"period-3 limit cycle", "periodic"}],

Cell[TextData[{
  "The ",
  StyleBox["Poincar\[EAcute] section",
    FontSlant->"Italic"],
  " provides a simplification of the phase diagram by sampling at time \
intervals equal to the period of the driving frequency.  "
}], "Text",
  CellTags->{"Poincar\[EAcute] section", "driving frequency"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the period using ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = \(2\ \[Pi]\)\/\[Omega]\)]],
  ". How many cycles were present in the first 100 seconds? ",
  StyleBox["[2 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["\<\
To avoid transient effects, the data for the first few cycles should be \
discarded.\
\>", "Text",
  CellTags->"transient effects"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Visualize the Poincar\[EAcute] section by applying ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " to a table of values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            
            InterpretationBox[\(\((\[Theta](
                      t) - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
              Mod[ 
                Plus[ 
                  \[Theta][ t], 
                  Times[ -1, Pi]], 
                Times[ 2, Pi]]], ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " between ",
  Cell[BoxData[
      \(TraditionalForm\`t = 10  \[Tau]\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", discarding the first 10 cycles) and 400 in steps of \[Tau]. Interpret \
the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Series solution"
}], "Subsection"],

Cell[TextData[{
  "The easiest way to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve differential equations such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "x", ")"}], 
            "+", \(k\^2\ \(y(x)\)\)}], "=", "0"}], TraditionalForm]]],
  " using series methods is direct expansion of the equation, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"series solution"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"eqn", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "x", ")"}], 
            "+", \(k\^2\ \(y(x)\)\), "+", \(\(O(x)\)\^7\)}], "==", "0"}]}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        InterpretationBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(\(y(0)\)\ k\^2\), "+", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{
                    SuperscriptBox["y", 
                      TagBox[\((3)\),
                        Derivative],
                      MultilineFunction->None], "(", "0", ")"}]}], ")"}], " ",
               "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]\[Prime]",
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((4)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^2\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((3)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((5)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^3\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((4)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((6)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^4\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/120\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((5)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/120\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((7)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^5\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/720\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((6)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/720\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((8)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^6\)}], "+", 
            InterpretationBox[\(O(x\^7)\),
              SeriesData[ x, 0, {}, 0, 7, 1]]}],
          SeriesData[ x, 0, {
            Plus[ 
              Times[ 
                Power[ k, 2], 
                y[ 0]], 
              Derivative[ 2][ y][ 0]], 
            Plus[ 
              Times[ 
                Power[ k, 2], 
                Derivative[ 1][ y][ 0]], 
              Derivative[ 3][ y][ 0]], 
            Plus[ 
              Times[ 
                Rational[ 1, 2], 
                Power[ k, 2], 
                Derivative[ 2][ y][ 0]], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 4][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 6], 
                Power[ k, 2], 
                Derivative[ 3][ y][ 0]], 
              Times[ 
                Rational[ 1, 6], 
                Derivative[ 5][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 24], 
                Power[ k, 2], 
                Derivative[ 4][ y][ 0]], 
              Times[ 
                Rational[ 1, 24], 
                Derivative[ 6][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 120], 
                Power[ k, 2], 
                Derivative[ 5][ y][ 0]], 
              Times[ 
                Rational[ 1, 120], 
                Derivative[ 7][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 720], 
                Power[ k, 2], 
                Derivative[ 6][ y][ 0]], 
              Times[ 
                Rational[ 1, 720], 
                Derivative[ 8][ y][ 0]]]}, 0, 7, 1]], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is equivalent to expanding ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " (and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "x", ")"}], TraditionalForm]]],
  ") into a power series."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`yseries = y(x) + \(O(x)\)\^7\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{\(y(0)\), "+", 
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", "x"}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^2\)}], 
          "+", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^3\)}], 
          "+", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((4)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^4\)}], 
          "+", 
          RowBox[{\(1\/120\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((5)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^5\)}], 
          "+", 
          RowBox[{\(1\/720\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((6)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^6\)}], 
          "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {
          y[ 0], 
          Derivative[ 1][ y][ 0], 
          Times[ 
            Rational[ 1, 2], 
            Derivative[ 2][ y][ 0]], 
          Times[ 
            Rational[ 1, 6], 
            Derivative[ 3][ y][ 0]], 
          Times[ 
            Rational[ 1, 24], 
            Derivative[ 4][ y][ 0]], 
          Times[ 
            Rational[ 1, 120], 
            Derivative[ 5][ y][ 0]], 
          Times[ 
            Rational[ 1, 720], 
            Derivative[ 6][ y][ 0]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can see that the expression multiplying each power of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the expansion of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "x", ")"}], 
          "+", \(k\^2\ \(y(x)\)\)}], TraditionalForm]]],
  " must vanish identically, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(y(0)\)\ k\^2\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
        TraditionalForm]]],
  ", \[Ellipsis]   To see the equations generated you can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["LogicalExpand",
          "Input"], TraditionalForm]]],
  " (this step is not required). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`LogicalExpand[eqn]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\(y(0)\)\ k\^2\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/6\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/24\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/120\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/120\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((7)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/720\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/720\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((8)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", 
          "0"}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " are ",
  StyleBox["not",
    FontSlant->"Italic"],
  " determined but that you can solve for the undetermined coefficients (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((3)\),
              Derivative],
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", \[Ellipsis]) in terms of the initial conditions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"Solve", "[", 
        RowBox[{"eqn", ",", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((n)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              ",", \({n, 2, 8}\)}], "]"}]}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((7)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(-k\^6\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((8)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(k\^8\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(k\^4\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\(-k\^6\)\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(k\^4\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\(-k\^2\)\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(-k\^2\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}]}], "}"}], 
        "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To obtain the series solution to the original equation you substitute \
these coefficients into the series expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`yseries /. First[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{\(y(0)\), "+", 
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", "x"}], 
          "-", \(1\/2\ \((k\^2\ \(y(0)\))\)\ x\^2\), "-", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{"(", 
              RowBox[{\(k\^2\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}], ")"}], 
            " ", \(x\^3\)}], "+", \(1\/24\ k\^4\ \(y(0)\)\ x\^4\), "+", 
          RowBox[{\(1\/120\), " ", \(k\^4\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^5\)}], 
          "-", \(1\/720\ \((k\^6\ \(y(0)\))\)\ x\^6\), "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {
          y[ 0], 
          Derivative[ 1][ y][ 0], 
          Times[ 
            Rational[ -1, 2], 
            Power[ k, 2], 
            y[ 0]], 
          Times[ 
            Rational[ -1, 6], 
            Power[ k, 2], 
            Derivative[ 1][ y][ 0]], 
          Times[ 
            Rational[ 1, 24], 
            Power[ k, 4], 
            y[ 0]], 
          Times[ 
            Rational[ 1, 120], 
            Power[ k, 4], 
            Derivative[ 1][ y][ 0]], 
          Times[ 
            Rational[ -1, 720], 
            Power[ k, 6], 
            y[ 0]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you now supply the initial conditions \[LongDash] say ",
  Cell[BoxData[
      \(TraditionalForm\`y(0) = 1\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "(", "0", ")"}], "=", "0"}], 
        TraditionalForm]]],
  " \[LongDash] you get "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"%", "/.", 
        RowBox[{"{", 
          RowBox[{\(y(0) \[Rule] 1\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              "0"}]}], "}"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{
        "1", "-", \(\(k\^2\ x\^2\)\/2\), "+", \(\(k\^4\ x\^4\)\/24\), 
          "-", \(\(k\^6\ x\^6\)\/720\), "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {1, 0, 
          Times[ 
            Rational[ -1, 2], 
            Power[ k, 2]], 0, 
          Times[ 
            Rational[ 1, 24], 
            Power[ k, 4]], 0, 
          Times[ 
            Rational[ -1, 720], 
            Power[ k, 6]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Series solution for the undamped pendulum"
}], "Subsection"],

Cell["We would like to analytically solve the equation", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "+", \(\[Omega]\^2\ \(sin(\[Theta](t))\)\)}], "=", "0."}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Obtain the series solution to equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation"],
  ") up to tenth order using the method of \[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "series solution"],
  " for the initial conditions, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{\(\[Theta](0) \[Rule] 0\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\[Omega]\_0\)}]}], "}"}], TraditionalForm]]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": it is a good idea to find the series solution to lower order first to \
check that you are doing the right thing.) ",
  StyleBox["[5 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[TextData[{
  "The ",
  StyleBox["linearized equation",
    FontSlant->"Italic"],
  " results by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\[Theta])\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ". "
}], "Text",
  CellTags->"linearized equation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "+", \(\[Omega]\^2\ \(\[Theta](t)\)\)}], "=", "0."}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the linearized ",
  "equation",
  " (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation"],
  ") taking into account the initial conditions. To what order do these \
solutions agree? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you can take the difference between the series solution and the exact \
solution to the linearized equation and simplify.)",
  " What does the difference say about the behaviour over a long period of \
time?",
  " ",
  StyleBox["[6 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Iterative Operations"
}], "Section"],

Cell["\<\
This section presents four examples of visualizing iterative operations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Julia set"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Julia set",
    FontSlant->"Italic"],
  " associated to a fixed complex number ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is found by iterating the map ",
  Cell[BoxData[
      \(TraditionalForm\`z \[RightTeeArrow] z\^2 + c\)]],
  ". The set of points, ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", that do not escape to infinity (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", their absolute value remains bounded, say ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 2\)]],
  ", after ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " iterations have been carried out) is the Julia set. "
}], "Text",
  CellTags->{"Iterated mapping", "Bounded absolute value"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter the function ",
  Cell[BoxData[
      \(TraditionalForm\`f[z_] := z\^2 + 0.5  \[ImaginaryI]\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", starting at ",
  Cell[BoxData[
      \(TraditionalForm\`c\  = \ 0.5\ \[ImaginaryI]\)]],
  ". ",
  StyleBox["Using ",
    FontSlant->"Plain"],
  StyleBox["NestList", "InlineInputTraditionalForm",
    FontSlant->"Plain"],
  StyleBox[", iterate ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  StyleBox[" ten times, starting at ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 0.1\)]],
  ". Compute the absolute value of these complex numbers. Are they remaining \
bounded? ",
  StyleBox["Try ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 0.5\)]],
  StyleBox[" and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 1\)]],
  StyleBox[" and comment.",
    FontSlant->"Plain"],
  " ",
  StyleBox["[5 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "The following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedural code (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", similar in style to Fortran, C, Pascal, Basic,\[Ellipsis]) iterates ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\^2 + c\)]],
  " for a particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ".  Either the value of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " escapes to \[Infinity] which can be tested using ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 
        2.0\)]],
  " or it hops around a finite number of times, bounded above by ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "."
}], "Text",
  CellTags->"Module"],

Cell[BoxData[
    \(TraditionalForm\`\(JuliaModule(w_, c_, m_) := 
        Module({z = w, n = 0}, 
          While(\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] n < m, 
            z = z\^2 + c; \(++n\)); n);\)\)], "Input"],

Cell[TextData[{
  "Alternatively, we can implement this as a pure function (using ",
  StyleBox["Function", "InlineInputTraditionalForm"],
  ") with ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({w, c, m}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " as ",
  StyleBox["dummy arguments",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->{"pure function", "Function"}],

Cell[BoxData[
    \(TraditionalForm\`\(JuliaFunction = 
        Function({w, c, m}, 
          Module({z = w, n = 0}, 
            While(\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] 
                n < m, z = z\^2 + c; \(++n\)); n));\)\)], "Input"],

Cell["\<\
A table of values using either implementation is somewhat slow:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(Table[
            JuliaModule(x + \[ImaginaryI]\ y, 1 + 0.3\ \[ImaginaryI], 
              35), {x, \(-1.5\), 1.5, 0.1}, {y, \(-1.5\), 1.5, 0.1}];\) // 
        Timing\) // First\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.41666666666606034`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(Table[
            JuliaFunction(x + \[ImaginaryI]\ y, 1 + 0.3\ \[ImaginaryI], 
              35), {x, \(-1.5\), 1.5, 0.1}, {y, \(-1.5\), 1.5, 0.1}];\) // 
        Timing\) // First\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.43333333333339397`\ Second\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Numerical function compilation, using ",
  StyleBox["Compile", "InlineInputTraditionalForm"],
  ", is a useful way of speeding up a computation. The following code expects \
three arguments: the point ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", the point ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", and the maximum number of iterations."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"JuliaCompile", "=", 
          RowBox[{"Compile", "[", 
            RowBox[{
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"w", "_Complex"},
                    {"c", "_Complex"},
                    {"m", "_Integer"}
                    }], "\[NoBreak]", ")"}], 
              ",", \(Module[{z = w, n = 0}, 
                While[\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] 
                    n < m, z = z\^2 + c; \(n++\)]; n]\)}], "]"}]}], ";"}], 
      TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compare the speed of ",
  StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["JuliaFunction", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "I don't expect you to get into the details of ",
  StyleBox["Compile", "InlineInputTraditionalForm"],
  " \[LongDash] just know that it can make code faster. For numerical \
functions, it is often advantageous writing them using ",
  Cell[BoxData[
      FormBox[
        StyleBox["Function",
          "Input"], TraditionalForm]]],
  " because it is straightforward to \"compile\" a function: usually it is \
only a matter of replacing ",
  Cell[BoxData[
      FormBox[
        StyleBox["Function",
          "Input"], TraditionalForm]]],
  " with ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " and \"typing\" the arguments. "
}], "Warning",
  CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
    "Compile", "argument typing"}],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " assumes its arguments should be compiled as ",
  ButtonBox["machine-precision",
    ButtonData:>{"3.1.6"},
    ButtonStyle->"MainBookLink"],
  " real numbers unless it is directed to do otherwise by variable \
declarations such as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({w, _Complex}\),
          "Input"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({m, _Integer}\),
          "Input"], TraditionalForm]]],
  "."
}], "Warning",
  CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
     "_Integer"}],

Cell[TextData[{
  "The first argument of ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " is a list of lists (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", a rank-2 tensor or matrix) and is typeset in ",
  Cell[BoxData[
      FormBox[
        StyleBox["TraditionalForm",
          "Input"], TraditionalForm]]],
  " as a matrix. You can either enter it as an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]2\)]],
  " matrix:"
}], "Warning"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"w", "_Complex"},
            {"c", "_Complex"},
            {"m", "_Integer"}
            }], ")"}], TraditionalForm]], "Input"],

Cell["or as a list of lists:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`{{w, _Complex}, {c, _Complex}, {m, _Integer}}\)], \
"Input"],

Cell[TextData[{
  "The variable types appearing in the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Module",
          "Input"], TraditionalForm]]],
  " part of ",
  Cell[BoxData[
      FormBox[
        StyleBox["JuliaCompile",
          "Input"], TraditionalForm]]],
  " are guessed based on the first time they are set. Since the local \
variable ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          "Input"], TraditionalForm]]],
  " is first initialized to ",
  Cell[BoxData[
      FormBox[
        StyleBox["w",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " knows it is a complex variable. Similarly, the statement ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(n = 0\),
          "Input"], TraditionalForm]]],
  " indicates to ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " that ",
  StyleBox["n", "InlineInputTraditionalForm",
    FontSlant->"Italic"],
  " is an integer. "
}], "Warning",
  CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Use ",
    FontSlant->"Plain"],
  StyleBox["DensityPlot", "InlineInputTraditionalForm"],
  StyleBox[" to visualize the Julia set over ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1.5\), \ 1.5]\)\ \[Times]\ \([\(-1.3\), \ 
          1.3]\)\)]],
  StyleBox[" in the complex plane for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`c\  = \ \[ImaginaryI]\)]],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Algorithms for computing fractal sets often involve iterating a formula \
until a specified condition is met. By default, ",
  StyleBox["FixedPoint", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " stop iterating when two successive calculations give the same result. To \
specify our own stopping condition, we can use the ",
  StyleBox["SameTest", "InlineInputTraditionalForm"],
  " option. This option takes a pure function of two arguments that returns \
",
  StyleBox["True", "InlineInputTraditionalForm"],
  " if the two arguments can be considered \[OpenCurlyDoubleQuote]the same\
\[CloseCurlyDoubleQuote]. For example, here we iterate the square root \
function, applied to 10, and stop when two successive values are within 0.1 \
of each other."
}], "Text",
  CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
    "SameTest", "pure function", "True"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FixedPoint(Sqrt, 10.0, 
      SameTest \[Rule] \((\[LeftBracketingBar]#1 - #2\[RightBracketingBar] < 
              0.1 &)\))\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1.0746078283213176`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Find a ",
    FontSlant->"Plain"],
  StyleBox["FixedPoint", "InlineInputTraditionalForm"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x)\)]],
  ", stopping when two successive values are within ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  " of each other. ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Here is an elegant alternative implementation of ",
  StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
  " using a ",
  StyleBox["fixed",
    FontSlant->"Italic"],
  " number of iterations (here 35)."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"JuliaCompile", "=", 
          RowBox[{"Compile", "(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"z", "_Complex"},
                    {"c", "_Complex"}
                    }], ")"}], 
              ",", \(Length(
                FixedPointList(#\^2 + c &, z, 35, 
                  SameTest \[Rule] \((\[LeftBracketingBar]#2\
\[RightBracketingBar] > 2.0 &)\)))\)}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "Using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(SameTest \[Rule] \((\[LeftBracketingBar]#2\
\[RightBracketingBar] > 2.0 &)\)\),
          "Input"], TraditionalForm]]],
  " ",
  "tests whether the last value (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["#2", "InlineInputTraditionalForm"],
  ") generated by ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " remains bounded (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[LeftBracketingBar]z\[RightBracketingBar]<2). The length of the result \
of ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " is the number of iterations."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Plot the Julia set associated with ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0.27334 + 0.00742\ \[ImaginaryI]\)]],
  " ",
  StyleBox["over ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z \[Element] \([\(-1.2\), \ 
            1.2]\)\ \[Times]\ \([\(-1.2\), \ 1.2]\)\)]],
  StyleBox[".",
    FontSlant->"Plain"],
  " ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"Julia set"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Interact with the plot of exercise ",
  
  CounterBox["Exercise", "Julia set"],
  " to find a point that is in the Julia set, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", click on the graphic, hold down the Apple key (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[CloverLeaf]) on a Macintosh or the Control key (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[ControlKey]) under Windows, and move the mouse around.  The \
mouse-coordinates will appear in the status box (bottom left corner of the \
Notebook).  Click at an appropriate point and copy the coordinate value(s) \
using Copy (\[CloverLeaf]-C or \[ControlKey]-V). Paste this value into the \
Notebook (in a new cell) and check that it is in the Julia set by applying ",
  StyleBox["JuliaComplie", "InlineInputTraditionalForm"],
  " to it. (Note that ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Complex\  @@ \ {a, \ b}\),
          "Input"], TraditionalForm]]],
  " yields the complex number ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Complex[a, \ b]\),
          "Input"], TraditionalForm]]],
  "). ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "For fun, run the following code to produce an array of plots with ",
  Cell[BoxData[
      \(TraditionalForm\`z\  \[Element] \ \([\(-1.1\) - 1.1  \[ImaginaryI], 
          1.1 + 1.1  \[ImaginaryI]]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c = 
        a + b\ \[ImaginaryI]\ \( \[Element] \_\ \)\([\(-2\) - \[ImaginaryI], 
            1 + \[ImaginaryI]]\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(Show(
        GraphicsArray(
          Table(DensityPlot(\(-\(JuliaCompile(x + \[ImaginaryI]\ y, 
                  a + b\ \[ImaginaryI])\)\), {x, \(-1.1\), 
                1.1}, {y, \(-1.1\), 1.1}, Frame \[Rule] False, 
              Axes \[Rule] False, PlotPoints \[Rule] 20, 
              DisplayFunction \[Rule] Identity), {b, \(-1\), 1, 
              1\/3}, {a, \(-2\), 1, 1\/3})));\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " The Mandelbrot set"
}], "Subsection"],

Cell[TextData[{
  "For each ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in the complex plane, those points that remain bounded upon iterating the \
map ",
  Cell[BoxData[
      \(TraditionalForm\`c \[RightTeeArrow] c\^2 + c\)]],
  " generate the ",
  StyleBox["Mandelbrot set",
    FontSlant->"Italic"],
  ". It turns out that points in the Mandelbrot set have connected Julia \
sets. "
}], "Text",
  CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Modify the Julia code to compute and visualize the Mandlebrot set. ",
  StyleBox["[6 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Newton's Method"
}], "Subsection"],

Cell[TextData[{
  "Consider using Newton's method to compute the (complex) argument of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-th roots of unity, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the roots of ",
  Cell[BoxData[
      \(TraditionalForm\`f(z) = z\^n - 1\)]],
  ". The Newton iteration, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Rule]", 
          RowBox[{"z", "-", 
            FractionBox[\(f(z)\), 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]]}]}], 
        TraditionalForm]]],
  ", becomes"
}], "Text",
  CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
    "Newton's method"}],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"z", "-", 
            FractionBox[\(f(z)\), 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]]}], 
          "/.", \(f \[Rule] Function(z, z\^n - 1)\)}], "//", "Simplify"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(z\ \((z\^\(-n\) + n - 1)\)\)\/n\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To evaluate both ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f(z)\),
          "Input"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], \((z)\)}],
          "Input"], TraditionalForm]]],
  " we use a pure function replacement rule for ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f \[Rule] Function(z, z\^n - 1)\),
          "Input"], TraditionalForm]]],
  "."
}], "BrightIdea",
  CellTags->"pure function replacement rule"],

Cell["The compiled function", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"NewtonIteration", "=", 
          RowBox[{"Compile", "(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"n", "_Integer"},
                    {"c", "_Complex"}
                    }], ")"}], 
              ",", \(Arg(
                FixedPoint(Function(z, \(z\ \((z\^\(-n\) + n - 1)\)\)\/n), c, 
                  35))\)}], ")"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "can be used to show the convergence of points in the complex plane for \
specific ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". "
}], "Text",
  CellTags->"attracting root"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 4\)]],
  ", visualize to which \[OpenCurlyDoubleQuote]attracting\
\[CloseCurlyDoubleQuote] root (out of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[PlusMinus]\[ImaginaryI]\),
          "Input"], TraditionalForm]]],
  ") the Newton iteration converges. Note that the color of each point is \
determined by the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Arg",
          "Input"], TraditionalForm]]],
  " of the attracting root ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Arg({\(+1\), \(-1\), \(+\[ImaginaryI]\), \
\(-\[ImaginaryI]\)})\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Interpret the result. ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "For fun, run the following code to produce an array of graphics (generated \
using ",
  Cell[BoxData[
      FormBox[
        StyleBox["GraphicsArray",
          "Input"], TraditionalForm]]],
  ") that show the convergence of points in the complex plane, for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ranging from 5 to 13."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(Show(
        GraphicsArray(
          Partition(
            Table(DensityPlot(
                NewtonIteration(n, x + \[ImaginaryI]\ y), {x, 
                  1.1, \(-1.1\)}, {y, \(-1.1\), 1.1}, PlotPoints \[Rule] 30, 
                Compiled \[Rule] False, Frame \[Rule] False, 
                DisplayFunction \[Rule] Identity), {n, 5, 13}), 3), 
          GraphicsSpacing \[Rule] 0.05));\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Feigenbaum Bifurcation Diagram"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Feigenbaum bifurcation diagram",
    FontSlant->"Italic"],
  " shows the behavior of iterates of ",
  Cell[BoxData[
      \(TraditionalForm\`x \[RightTeeArrow] \[Lambda]\ x\ \((1 - x)\)\)]],
  " and displays the ",
  StyleBox["period-doubling route to chaos",
    FontSlant->"Italic"],
  ". The following code iterates this mapping 300 times using ",
  Cell[BoxData[
      FormBox[
        StyleBox["NestList",
          "Input"], TraditionalForm]]],
  " and then deletes the first 100 iterations (during which time the \
iteration \[OpenCurlyDoubleQuote]settles down\[CloseCurlyDoubleQuote])."
}], "Text",
  CellTags->{
  "NestList", "period-doubling route to chaos", 
    "Feigenbaum bifurcation diagram"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Feigenbaum", "=", 
          RowBox[{"Compile", "[", 
            RowBox[{
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\[Lambda]", "_Real"}
                    }], "\[NoBreak]", ")"}], 
              ",", \(\(({\[Lambda], #} &)\) /@ 
                Drop[NestList[Function[x, \[Lambda]\ x\ \((1 - x)\)], 0.2, 
                    300], 100]\)}], "]"}]}], ";"}], TraditionalForm]], "Input",\

  CellTags->"Feigenbaum"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Lambda]values = 
              Flatten[Table[
                  Feigenbaum[\[Lambda]], {\[Lambda], 1.0, 4.0, 0.005}], 1];\),
          
          FontWeight->"Bold"], TraditionalForm]]],
  " generates a table of iterated values for ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Lambda]",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " ranging from 1 to 4 in steps of 0.005.  Visualize ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Union[\[Lambda]values]\),
          "Input"], TraditionalForm]]],
  " using ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  ". (",
  StyleBox["Union", "InlineInputTraditionalForm"],
  " eliminates duplicates.) Where does period-doubling commence? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Fvalues = Last /@ \[Lambda]values;\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to obtain a list of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Feigenbaum[\[Lambda]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " values. Listen to ",
  StyleBox["Fvalues", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["ListPlay", "InlineInputTraditionalForm"],
  ". Describe what you hear. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->None,
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{823, 657},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title resets all cell \
CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, Subtitle states \
topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading in a \
notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. Sets counter \
values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a subsection \
level heading directly follows a section level heading. Sets counter \
Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by either \
Question or Input/Output etc. Last paragraph of the question should be in \
EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after a section \
cell. Used if the question is a single text paragraph.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or BeginEndQuestion cell \
style to begin the answer portion. Followed by Text or Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published elsewhere (and \
appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input cell, not \
followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell has \
ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells embedded within \
another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want to number \
sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Figure \
and the NumberedFigure counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Table and \
the NumberedTable counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Listing \
and the NumberedProgram counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of FilledSmallCircle. \
Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list sequence. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the List \
counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list sequence with \
a single digit. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered list sequence \
with two digits. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a notebook. One \
cell for each bibliography entry. Use the TMJAuthorPalette.nb palette to \
begin cell and paste in the Reference counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes the Title \
cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). Author name(s) \
may be preced by \"Edited by \" for certain columns. Text in author cell to \
be used as the left page header. Usually followed by an Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact information \
for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short descriptive \
summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with the Help \
Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed tabular material. \
Can be followed by NumberedTableCaption cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other cells.  If the \
FormatType of a cell style matches the name of one of the styles defined \
below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "harmonic approximation"->{
    Cell[4823, 171, 388, 15, 33, "Text",
      CellTags->"harmonic approximation"]},
  "damping"->{
    Cell[5355, 192, 433, 15, 56, "Text",
      CellTags->{"damping", "sinusoidal driving term"}]},
  "sinusoidal driving term"->{
    Cell[5355, 192, 433, 15, 56, "Text",
      CellTags->{"damping", "sinusoidal driving term"}]},
  "undamped pendulum"->{
    Cell[6494, 240, 194, 6, 70, "Text",
      CellTags->"undamped pendulum"]},
  "phase-space plot"->{
    Cell[7066, 260, 1508, 40, 70, "BeginEndQuestion",
      CellTags->"phase-space plot"]},
  "damped pendulum"->{
    Cell[58586, 1547, 213, 6, 70, "Text",
      CellTags->"damped pendulum"]},
  "period-3 limit cycle"->{
    Cell[63714, 1720, 301, 9, 70, "Text",
      CellTags->{"period-3 limit cycle", "periodic"}]},
  "periodic"->{
    Cell[63714, 1720, 301, 9, 70, "Text",
      CellTags->{"period-3 limit cycle", "periodic"}]},
  "Poincar\[EAcute] section"->{
    Cell[64018, 1731, 297, 7, 70, "Text",
      CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
  "driving frequency"->{
    Cell[64018, 1731, 297, 7, 70, "Text",
      CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
  "transient effects"->{
    Cell[64612, 1751, 141, 4, 70, "Text",
      CellTags->"transient effects"]},
  "series solution"->{
    Cell[65964, 1808, 575, 18, 70, "Text",
      CellTags->"series solution"]},
  "linearized equation"->{
    Cell[89017, 2525, 292, 12, 70, "Text",
      CellTags->"linearized equation"]},
  "Iterated mapping"->{
    Cell[90713, 2610, 773, 24, 70, "Text",
      CellTags->{"Iterated mapping", "Bounded absolute value"}],
    Cell[106346, 3143, 485, 14, 70, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "Bounded absolute value"->{
    Cell[90713, 2610, 773, 24, 70, "Text",
      CellTags->{"Iterated mapping", "Bounded absolute value"}]},
  "Module"->{
    Cell[92583, 2679, 765, 25, 70, "Text",
      CellTags->"Module"]},
  "pure function"->{
    Cell[93585, 2712, 402, 13, 70, "Text",
      CellTags->{"pure function", "Function"}],
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "Function"->{
    Cell[93585, 2712, 402, 13, 70, "Text",
      CellTags->{"pure function", "Function"}],
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "rank-2 tensor"->{
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "TraditionalForm"->{
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "numerical functions"->{
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "Compile"->{
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}],
    Cell[97173, 2829, 709, 24, 70, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "argument typing"->{
    Cell[96328, 2803, 842, 24, 70, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "machine-precision numbers"->{
    Cell[97173, 2829, 709, 24, 70, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "variable declarations"->{
    Cell[97173, 2829, 709, 24, 70, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "_Complex"->{
    Cell[97173, 2829, 709, 24, 70, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "_Integer"->{
    Cell[97173, 2829, 709, 24, 70, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "Guessing variable types"->{
    Cell[98739, 2889, 1159, 42, 70, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "local variable"->{
    Cell[98739, 2889, 1159, 42, 70, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "JuliaCompile"->{
    Cell[98739, 2889, 1159, 42, 70, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "FixedPoint"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "FixedPointList"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "fractal sets"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "stopping condition"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "SameTest"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "True"->{
    Cell[100450, 2953, 972, 19, 70, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "Julia set"->{
    Cell[103574, 3051, 488, 17, 70, "BeginEndQuestion",
      CellTags->"Julia set"]},
  "connected Julia sets"->{
    Cell[106346, 3143, 485, 14, 70, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "Mandelbrot set"->{
    Cell[106346, 3143, 485, 14, 70, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "complex argument"->{
    Cell[107212, 3181, 749, 24, 70, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "n-th roots of unity"->{
    Cell[107212, 3181, 749, 24, 70, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "Newton iteration"->{
    Cell[107212, 3181, 749, 24, 70, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "Newton's method"->{
    Cell[107212, 3181, 749, 24, 70, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "pure function replacement rule"->{
    Cell[108456, 3225, 697, 26, 70, "BrightIdea",
      CellTags->"pure function replacement rule"]},
  "attracting root"->{
    Cell[109660, 3269, 201, 7, 70, "Text",
      CellTags->"attracting root"]},
  "NestList"->{
    Cell[111811, 3350, 746, 20, 70, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "period-doubling route to chaos"->{
    Cell[111811, 3350, 746, 20, 70, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "Feigenbaum bifurcation diagram"->{
    Cell[111811, 3350, 746, 20, 70, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "Feigenbaum"->{
    Cell[112560, 3372, 505, 13, 70, "Input",
      CellTags->"Feigenbaum"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"harmonic approximation", 178893, 5732},
  {"damping", 178993, 5735},
  {"sinusoidal driving term", 179123, 5738},
  {"undamped pendulum", 179247, 5741},
  {"phase-space plot", 179350, 5744},
  {"damped pendulum", 179465, 5747},
  {"period-3 limit cycle", 179572, 5750},
  {"periodic", 179686, 5753},
  {"Poincar\[EAcute] section", 179816, 5756},
  {"driving frequency", 179952, 5759},
  {"transient effects", 180088, 5762},
  {"series solution", 180192, 5765},
  {"linearized equation", 180299, 5768},
  {"Iterated mapping", 180407, 5771},
  {"Bounded absolute value", 180678, 5777},
  {"Module", 180801, 5780},
  {"pure function", 180893, 5783},
  {"Function", 181187, 5790},
  {"rank-2 tensor", 181482, 5797},
  {"TraditionalForm", 181688, 5802},
  {"numerical functions", 181898, 5807},
  {"Compile", 182096, 5812},
  {"argument typing", 182472, 5821},
  {"machine-precision numbers", 182688, 5826},
  {"variable declarations", 182888, 5831},
  {"_Complex", 183075, 5836},
  {"_Integer", 183262, 5841},
  {"Guessing variable types", 183464, 5846},
  {"local variable", 183621, 5850},
  {"JuliaCompile", 183776, 5854},
  {"FixedPoint", 183929, 5858},
  {"FixedPointList", 184138, 5863},
  {"fractal sets", 184345, 5868},
  {"stopping condition", 184558, 5873},
  {"SameTest", 184761, 5878},
  {"True", 184960, 5883},
  {"Julia set", 185164, 5888},
  {"connected Julia sets", 185279, 5891},
  {"Mandelbrot set", 185434, 5895},
  {"complex argument", 185591, 5899},
  {"n-th roots of unity", 185780, 5904},
  {"Newton iteration", 185966, 5909},
  {"Newton's method", 186151, 5914},
  {"pure function replacement rule", 186351, 5919},
  {"attracting root", 186476, 5922},
  {"NestList", 186572, 5925},
  {"period-doubling route to chaos", 186770, 5930},
  {"Feigenbaum bifurcation diagram", 186968, 5935},
  {"Feigenbaum", 187146, 5940}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 45, 0, 31, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1824, 55, 127, 5, 100, "Title",
  CounterAssignments->{{"Title", 0}}],
Cell[1954, 62, 29, 0, 33, "Author"],
Cell[1986, 64, 436, 12, 124, "Address"],

Cell[CellGroupData[{
Cell[2447, 80, 39, 0, 52, "Subsubsection"],
Cell[2489, 82, 215, 5, 70, "Text"],
Cell[2707, 89, 112, 2, 70, "Input",
  InitializationCell->True],
Cell[2822, 93, 85, 2, 70, "Text"],
Cell[2910, 97, 117, 2, 70, "Input",
  InitializationCell->True],
Cell[3030, 101, 270, 8, 70, "Text"],
Cell[3303, 111, 175, 4, 70, "Input",
  InitializationCell->True],
Cell[3481, 117, 245, 5, 70, "Input",
  InitializationCell->True],
Cell[3729, 124, 182, 4, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3948, 133, 165, 9, 50, "SectionFirst",
  Evaluatable->False],
Cell[4116, 144, 286, 9, 56, "Text"],
Cell[4405, 155, 169, 3, 44, "NumberedEquation"],
Cell[4577, 160, 243, 9, 35, "Text"],
Cell[4823, 171, 388, 15, 33, "Text",
  CellTags->"harmonic approximation"],
Cell[5214, 188, 138, 2, 32, "NumberedEquation"],
Cell[5355, 192, 433, 15, 56, "Text",
  CellTags->{"damping", "sinusoidal driving term"}],
Cell[5791, 209, 237, 4, 32, "NumberedEquation"],
Cell[6031, 215, 280, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[6336, 228, 155, 10, 68, "Subsection"],
Cell[6494, 240, 194, 6, 70, "Text",
  CellTags->"undamped pendulum"],
Cell[6691, 248, 372, 10, 70, "Input"],
Cell[7066, 260, 1508, 40, 70, "BeginEndQuestion",
  CellTags->"phase-space plot"],

Cell[CellGroupData[{
Cell[8599, 304, 32, 0, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[8656, 308, 817, 19, 70, "Input"],
Cell[9476, 329, 624, 16, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10137, 350, 446, 11, 70, "Input"],
Cell[10586, 363, 45421, 1080, 70, 13751, 684, "GraphicsData", "PostScript", \
"Graphics"],
Cell[56010, 1445, 167, 4, 70, "Output"]
}, Open  ]],
Cell[56192, 1452, 422, 13, 70, "Warning"],
Cell[56617, 1467, 461, 14, 70, "BeginEndQuestion"],
Cell[57081, 1483, 444, 15, 70, "BeginEndQuestion"],
Cell[57528, 1500, 19, 0, 70, "Answer"],
Cell[57550, 1502, 809, 25, 70, "BeginEndQuestion"],
Cell[58362, 1529, 19, 0, 70, "Answer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58430, 1535, 153, 10, 70, "Subsection"],
Cell[58586, 1547, 213, 6, 70, "Text",
  CellTags->"damped pendulum"],
Cell[58802, 1555, 564, 14, 70, "Input"],
Cell[59369, 1571, 740, 23, 70, "BeginEndQuestion"],
Cell[60112, 1596, 19, 0, 70, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[60168, 1601, 160, 10, 70, "Subsection"],
Cell[60331, 1613, 137, 5, 70, "Text"],
Cell[60471, 1620, 608, 15, 70, "Input"],
Cell[61082, 1637, 1468, 40, 70, "BeginEndQuestion"],
Cell[62553, 1679, 18, 0, 70, "Answer"],
Cell[62574, 1681, 1116, 35, 70, "BeginEndQuestion"],
Cell[63693, 1718, 18, 0, 70, "Answer"],
Cell[63714, 1720, 301, 9, 70, "Text",
  CellTags->{"period-3 limit cycle", "periodic"}],
Cell[64018, 1731, 297, 7, 70, "Text",
  CellTags->{"Poincar\[EAcute] section", "driving frequency"}],
Cell[64318, 1740, 291, 9, 70, "BeginEndQuestion"],
Cell[64612, 1751, 141, 4, 70, "Text",
  CellTags->"transient effects"],
Cell[64756, 1757, 994, 32, 70, "BeginEndQuestion"],
Cell[65753, 1791, 18, 0, 70, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[65808, 1796, 153, 10, 70, "Subsection"],
Cell[65964, 1808, 575, 18, 70, "Text",
  CellTags->"series solution"],

Cell[CellGroupData[{
Cell[66564, 1830, 335, 9, 70, "Input"],
Cell[66902, 1841, 5970, 160, 70, "Output"]
}, Open  ]],
Cell[72887, 2004, 328, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[73240, 2019, 78, 1, 70, "Input"],
Cell[73321, 2022, 2081, 60, 70, "Output"]
}, Open  ]],
Cell[75417, 2085, 1444, 46, 70, "Text"],

Cell[CellGroupData[{
Cell[76886, 2135, 68, 1, 70, "Input"],
Cell[76957, 2138, 3478, 99, 70, "Output"]
}, Open  ]],
Cell[80450, 2240, 870, 28, 70, "Text"],

Cell[CellGroupData[{
Cell[81345, 2272, 407, 11, 70, "Input"],
Cell[81755, 2285, 2372, 61, 70, "Output"]
}, Open  ]],
Cell[84142, 2349, 210, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[84377, 2359, 69, 1, 70, "Input"],
Cell[84449, 2362, 1606, 45, 70, "Output"]
}, Open  ]],
Cell[86070, 2410, 391, 13, 70, "Text"],

Cell[CellGroupData[{
Cell[86486, 2427, 343, 9, 70, "Input"],
Cell[86832, 2438, 586, 17, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[87467, 2461, 179, 10, 70, "Subsection"],
Cell[87649, 2473, 64, 0, 70, "Text"],
Cell[87716, 2475, 309, 8, 70, "NumberedEquation"],
Cell[88028, 2485, 986, 38, 70, "BeginEndQuestion"],
Cell[89017, 2525, 292, 12, 70, "Text",
  CellTags->"linearized equation"],
Cell[89312, 2539, 304, 8, 70, "NumberedEquation"],
Cell[89619, 2549, 627, 25, 70, "BeginEndQuestion"],
Cell[90249, 2576, 18, 0, 70, "Answer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90316, 2582, 123, 8, 70, "Section"],
Cell[90442, 2592, 96, 2, 70, "Text"],

Cell[CellGroupData[{
Cell[90563, 2598, 147, 10, 70, "Subsection"],
Cell[90713, 2610, 773, 24, 70, "Text",
  CellTags->{"Iterated mapping", "Bounded absolute value"}],
Cell[91489, 2636, 1070, 39, 70, "BeginEndQuestion"],
Cell[92562, 2677, 18, 0, 70, "Answer"],
Cell[92583, 2679, 765, 25, 70, "Text",
  CellTags->"Module"],
Cell[93351, 2706, 231, 4, 70, "Input"],
Cell[93585, 2712, 402, 13, 70, "Text",
  CellTags->{"pure function", "Function"}],
Cell[93990, 2727, 258, 5, 70, "Input"],
Cell[94251, 2734, 87, 2, 70, "Text"],

Cell[CellGroupData[{
Cell[94363, 2740, 233, 4, 70, "Input"],
Cell[94599, 2746, 79, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94715, 2752, 235, 4, 70, "Input"],
Cell[94953, 2758, 79, 1, 70, "Output"]
}, Open  ]],
Cell[95047, 2762, 392, 11, 70, "Text"],
Cell[95442, 2775, 606, 15, 70, "Input"],
Cell[96051, 2792, 274, 9, 70, "BeginEndQuestion"],
Cell[96328, 2803, 842, 24, 70, "Warning",
  CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
    "Compile", "argument typing"}],
Cell[97173, 2829, 709, 24, 70, "Warning",
  CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
     "_Integer"}],
Cell[97885, 2855, 509, 18, 70, "Warning"],
Cell[98397, 2875, 198, 6, 70, "Input"],
Cell[98598, 2883, 38, 0, 70, "Text"],
Cell[98639, 2885, 97, 2, 70, "Input"],
Cell[98739, 2889, 1159, 42, 70, "Warning",
  CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],
Cell[99901, 2933, 546, 18, 70, "BeginEndQuestion"],
Cell[100450, 2953, 972, 19, 70, "Text",
  CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
    "SameTest", "pure function", "True"}],

Cell[CellGroupData[{
Cell[101447, 2976, 175, 3, 70, "Input"],
Cell[101625, 2981, 70, 1, 70, "Output"]
}, Open  ]],
Cell[101710, 2985, 418, 15, 70, "BeginEndQuestion"],
Cell[102131, 3002, 238, 7, 70, "Text"],
Cell[102372, 3011, 514, 14, 70, "Input"],
Cell[102889, 3027, 682, 22, 70, "Text"],
Cell[103574, 3051, 488, 17, 70, "BeginEndQuestion",
  CellTags->"Julia set"],
Cell[104065, 3070, 1221, 33, 70, "BeginEndQuestion"],
Cell[105289, 3105, 414, 11, 70, "Text"],
Cell[105706, 3118, 444, 8, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[106187, 3131, 156, 10, 70, "Subsection"],
Cell[106346, 3143, 485, 14, 70, "Text",
  CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],
Cell[106834, 3159, 185, 5, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[107056, 3169, 153, 10, 70, "Subsection"],
Cell[107212, 3181, 749, 24, 70, "Text",
  CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
    "Newton's method"}],

Cell[CellGroupData[{
Cell[107986, 3209, 368, 10, 70, "Input"],
Cell[108357, 3221, 84, 1, 70, "Output"]
}, Open  ]],
Cell[108456, 3225, 697, 26, 70, "BrightIdea",
  CellTags->"pure function replacement rule"],
Cell[109156, 3253, 37, 0, 70, "Text"],
Cell[109196, 3255, 461, 12, 70, "Input"],
Cell[109660, 3269, 201, 7, 70, "Text",
  CellTags->"attracting root"],
Cell[109864, 3278, 898, 29, 70, "BeginEndQuestion"],
Cell[110765, 3309, 18, 0, 70, "Answer"],
Cell[110786, 3311, 366, 11, 70, "Text"],
Cell[111155, 3324, 448, 9, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[111640, 3338, 168, 10, 70, "Subsection"],
Cell[111811, 3350, 746, 20, 70, "Text",
  CellTags->{
  "NestList", "period-doubling route to chaos", 
    "Feigenbaum bifurcation diagram"}],
Cell[112560, 3372, 505, 13, 70, "Input",
  CellTags->"Feigenbaum"],
Cell[113068, 3387, 895, 27, 70, "BeginEndQuestion"],
Cell[113966, 3416, 18, 0, 70, "Answer"],
Cell[113987, 3418, 611, 19, 70, "BeginEndQuestion"],
Cell[114601, 3439, 18, 0, 70, "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

