(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     66379,       2411]*)
(*NotebookOutlinePosition[    144913,       5055]*)
(*  CellTagsIndexPosition[    142871,       4999]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell["Exam 2003", "Title"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\n35 Stirling \
Highway\nCrawley WA 6009\nAUSTRALIA\n\nURL: ",
  ButtonBox["physics.uwa.edu.au/Physics/Courses/Third_Year/Computational_\
Physics.html",
    ButtonData:>{
      URL[ 
      "http://physics.uwa.edu.au/Courses/Third_Year/Computational_Physics.\
html"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Instructions", "Subsection"],

Cell["\<\
This exam, worth 40% of the total mark for Computational Physics, is due in \
on Friday May 2 at 4pm.\
\>", "Text"],

Cell[TextData[{
  "Attempt 5 of 6 questions. The marks for each question and each part is \
indicated in red brackets (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["[", "Marks"],
  StyleBox["n", "Marks",
    FontSlant->"Italic"],
  StyleBox["]", "Marks"],
  ") and, obviously, the marks provide a good guide to the question's \
difficulty. Bonus marks will be given for elegant or unconventional \
solutions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plagiarism", "Subsection"],

Cell[TextData[{
  "I quote from the Departmental ",
  StyleBox["Guidelines on Plagiarism",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell["\<\
Like the scientific process, assessment of students relies on the integrity \
of the participants. The Department expects that any piece of work submitted \
by a student for assessment will be essentially their own work, and that \
contributions of others to that work will be appropriately acknowledged. In \
essence, students are expected to write their own essays and assignments, \
just as they are expected to sit the exams themselves.\
\>", "Quote"],

Cell["\<\
Students should generally avoid verbatim copying of published work, even when \
the work is cited. They are strongly encouraged to express their knowledge \
and thoughts in their own words, rather than those of others, as this greatly \
assists the learning process. It is acknowledged however that in some \
circumstances it is desirable to quote directly from a published work.\
\>", "Quote"],

Cell[TextData[{
  "Please do not leave copies of your working Notebooks in public locations, \
such as on the computers in the second- or third-year laboratory. I recommend \
that you backup your solutions to a password-secured area, such as to your \
tartarus account. Note that, when I mark the exam papers, I find it \
particularly easy to spot answers, or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code, that is common to more than one student."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell["Submitting your Solution", "Subsection"],

Cell[TextData[{
  "Name your exam solution using your initials, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["PCA.nb", "InlineInputTraditionalForm"],
  ", and submit to ",
  ButtonBox["ftp://ftp.physics.uwa.edu.au/incoming/Exam",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/incoming/Exam"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsection"],

Cell["\<\
You are asked whether you want to load the following code automatically each \
time the kernel is started.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Plotting", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Equations", "Subsubsection"],

Cell[TextData[{
  "We modify ",
  Cell[BoxData[
      FormBox[
        StyleBox["Equal",
          "Input"], TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      FormBox[
        StyleBox["Listable",
          "Input"], TraditionalForm]]],
  " operations are automatically applied to both sides of any equality:"
}], "Text",
  CellTags->{"Equal", "Listable"}],

Cell[BoxData[
    \(TraditionalForm\`\(Unprotect[Equal];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`listableQ(f_) := 
      MemberQ(Attributes(f), Listable)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`Equal /: \ 
      lhs : f_Symbol?
            listableQ[___, \ _Equal, \ ___]\  := \n\ \ \ \ \ \ \ \ Thread[\ 
        Unevaluated[lhs], \ Equal\ ]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`\(Protect[Equal];\)\)], "Input",
  InitializationCell->True],

Cell["Now, we can directly manipulate equations.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Roots in Range", "Subsubsection"],

Cell[BoxData[
    \(TraditionalForm\`Needs["\<Utilities`FilterOptions`\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`RootsInRange(\[Delta]_, {\[Lambda]_, \[Lambda]min_, \
\[Lambda]max_}, opts___) := 
      Module[{p, pts, x, f = Function[\[Lambda], Evaluate[\[Delta]]]}, 
        p = Plot[f(\[Lambda]), {\[Lambda], \[Lambda]min, \[Lambda]max}, 
            Compiled \[Rule] False, Evaluate[FilterOptions(Plot, opts)]]; 
        pts = Cases[First[p], Line[{x__}] \[Rule] x, \[Infinity]]; 
        pts = Map[First, 
            Select[Split[pts, sgn(Last[#2]) == \(-\(sgn(Last[#1])\)\) &], 
              Length[#1] == 2 &], {2}]; \((FindRoot[
                f(\[Lambda]) == 0, {\[Lambda], ##1}, 
                Evaluate[FilterOptions(FindRoot, opts)]] &)\) /@ 
          pts]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`\(RootsInRange::usage = \
"\<RootsInRange[f,{x,xmin,xmax}] generates a plot of f as a
function of x from xmin to xmax and then uses FindRoot to determine the roots \
of f
in the range (xmin,xmax).\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Load J/Link and URLToStream", "Subsubsection"],

Cell[BoxData[
    \(TraditionalForm\`\(Off[General::"\<spell\>", 
        General::"\<spell1\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`\(Needs["\<JLink`\>"];\)\)], "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False],

Cell["Code for opening and reading from a URL stream.", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(URLToStream::usage = "\<URLToStream[url_String] \
reads the contents of URL and converts it to a stream suitable for processing \
by Import, Read, ReadList, etc.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`\(URLToStream[url_String] := 
        JavaBlock[
          Module[{u, s, stream, numRead, outFile, buf}, 
            InstallJava[]; \[IndentingNewLine]u = 
              JavaNew["\<java.net.URL\>", url]; \[IndentingNewLine]stream = 
              u[openStream[]]; \[IndentingNewLine]If[stream === $Failed, 
              Return[$Failed]]; \[IndentingNewLine]buf = 
              JavaNew["\<[B\>", 
                5000]; \[IndentingNewLine]s = "\<\>"; \
\[IndentingNewLine]While[\((numRead = stream[read[buf]])\) > 0, 
              s = s <> FromCharacterCode[\((If[# < 0, # + 256, #] &)\) /@ 
                      Take[Val[buf], numRead]]]; \[IndentingNewLine]\ 
            stream[close[]]; \[IndentingNewLine]StringToStream[
              s]]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Analysis of Pulsar Timing Data ",
  StyleBox["[20]", "Marks"]
}], "SectionFirst"],

Cell[TextData[{
  "Alex Wolszczan has studied timing variations for the pulsar PSR B1257+12 \
over a 3-year period (see Wolszczan, A. & Frail, D., 1992, ",
  StyleBox["Nature",
    FontSlant->"Italic"],
  ", 255:145, \"A Planetary System around the Millisecond Pulsar \
PSR1257+12\"; Wolszczan, A., 1994, ",
  StyleBox["Science",
    FontSlant->"Italic"],
  ", ",
  StyleBox["264",
    FontWeight->"Bold"],
  ":538, \"Confirmation of Earth-Mass Planets Orbiting the Millisecond Pulsar \
PSR B1257+12\"; ",
  ButtonBox["http://www.astro.psu.edu/users/pspm/planets.html",
    ButtonData:>{
      URL[ "http://www.astro.psu.edu/users/pspm/planets.html"], None},
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text",
  CellTags->"pulsar PSR1257+12"],

Cell["\<\
Ordinarily, pulsars are highly regular astronomical clocks. Suppose however \
that the pulsar has one heavy unseen companion.  Then the pulsar will orbit \
around the centre of mass of the combined system, sometimes moving towards \
the earth and sometimes away from it.  This will lead to a sinusoidal \
variation in the timings as measured by an earth-based observer. If there is \
more than one unseen companion the timing variation will be more complicated \
but, to a good approximation, will be a linear superposition of sinusoidal \
variations with differing periods.\
\>", "Text"],

Cell[TextData[{
  "The timing variations for PSR B1257+12 indicate that it is orbited by at \
least two \"planets\".  The data in the file",
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(pulsar . dat\),
          "Input"], TraditionalForm]]],
  " (kindly supplied by Alex Wolszczan and available at ",
  ButtonBox["ftp://ftp.physics.uwa.edu.au/pub/Data/pulsar.dat",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/pub/Data/pulsar.dat"], None},
    ButtonStyle->"Hyperlink"],
  ") represent post-fit residuals after fitting out a standard timing model \
assuming a single pulsar (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", taking into account the earth's orbital motion, ",
  StyleBox["etc",
    FontSlant->"Italic"],
  "). In this exercise you will fit a double planet model to the data and \
determine the orbital periods of each planet."
}], "Text",
  CellTags->{"timing residuals", "Alex Wolszczan"}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Import the pulsar timing data and call the result ",
  Cell[BoxData[
      FormBox[
        StyleBox["data",
          "Input"], TraditionalForm]]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Select columns 2 (",
    FontSlant->"Plain"],
  StyleBox["epoch",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Plain"],
  StyleBox["i.e.",
    FontSlant->"Italic"],
  StyleBox[", time in decimal years) and 3 (",
    FontSlant->"Plain"],
  StyleBox["residual",
    FontSlant->"Italic"],
  StyleBox[" in ms) of ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["data",
          "Input"], TraditionalForm]]],
  StyleBox[". It is a good idea to subtract 1990 from all the epoch values. ",
    
    FontSlant->"Plain"],
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Visualise the residuals and describe the basic features. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"residuals"],

Cell[TextData[{
  "The discrete Fourier transform (DFT) can be used to determine the \
principal frequencies of a periodic system. However, ",
  Cell[BoxData[
      FormBox[
        StyleBox["Fourier",
          "Input"], TraditionalForm]]],
  " can only be used for ",
  StyleBox["uniformly",
    FontWeight->"Bold"],
  " sampled data. One way to approximately determine the orbital frequencies \
is to interpolate the timing data, re-sample it uniformly, and then apply ",
  Cell[BoxData[
      FormBox[
        StyleBox["Fourier",
          "Input"], TraditionalForm]]],
  ". This is somewhat clumsy and introduces additional numerical error.  \
There is a simple spectral analysis method that avoids interpolation and \
resampling: For each frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", fit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\ \(sin(\[Omega]\ t)\) + \[Beta]\ \(cos(\
\[Omega]\ t)\)\)]],
  " to the data by ",
  StyleBox["linear",
    FontSlant->"Italic"],
  " least-squares (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", using ",
  Cell[BoxData[
      FormBox[
        StyleBox["Fit",
          "Input"], TraditionalForm]]],
  "). The spectral energy ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE](\[Omega])\)]],
  " is then the square amplitude integrated over one period, ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2\ \[Pi]/\[Omega]\)]],
  " (normalised by dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ")."
}], "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{
  "Fourier", "astronomical time-series data", "spectral analysis", 
    "irregularly sampled data", "interpolation", "resampling", 
    "linear least-squares", "spectral energy"}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Show that the spectral energy of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\ \(sin(\[Omega]\ t)\) + \[Beta]\ \(cos(\
\[Omega]\ t)\)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE](\[Omega]) = \(\(1\/2\)\(\ \)\((\
\[Alpha]\^2 + \[Beta]\^2)\)\(\ \)\)\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compute and plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE](\[Omega])\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        StyleBox["data",
          "Input"], TraditionalForm]]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] \[Element] \([1, 50]\)\)]],
  ". ",
  StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Find the two principal frequencies for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] \[Element] \([1, 50]\)\)]],
  ". Since all times are in fractions of decimal years, express the periods \
corresponding to the principal frequencies in days. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Since we now have good estimates for the orbital periods, it is easy to \
do a nonlinear fit of a double planet model:"
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\(model(a_, 
          b_, \[Theta]_, \[Gamma]_, \[Phi]_, \[Delta]_, \[Epsilon]_) = 
        a\ \(sin(\[Theta]\ t + \[Gamma])\) + 
          b\ \(sin(\[Phi]\ t + \[Delta])\) + \[Epsilon];\)\)], "Input"],

Cell[TextData[{
  "Use the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Statistics`NonlinearFit`",
          "Input"], TraditionalForm]]],
  " package ",
  StyleBox["and the ",
    FontSlant->"Plain"],
  "principal frequencies",
  StyleBox[" determined in the previous section to determine the optimal \
values of ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["a",
          "Input"], TraditionalForm]]],
  StyleBox[",  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["b",
          "Input"], TraditionalForm]]],
  StyleBox[",  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Theta]",
          "Input"], TraditionalForm]]],
  StyleBox[",  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Gamma]",
          "Input"], TraditionalForm]]],
  StyleBox[",  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Phi]",
          "Input"], TraditionalForm]]],
  StyleBox[",  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Delta]",
          "Input"], TraditionalForm]]],
  StyleBox[",  and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Epsilon]",
          "Input"], TraditionalForm]]],
  ". The principal frequencies provide good starting values for ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Theta]",
          "Input"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Phi]",
          "Input"], TraditionalForm]]],
  " in the nonlinear fitting routine. The option ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(ShowProgress \[Rule] True\),
          "Input"], TraditionalForm]]],
  " may be useful. Compare the resulting best-fit with the timing residuals \
visualised in question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "residuals"],
  ". ",
  StyleBox["[5]", "Marks"]
}], "EndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Wavelets ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "Wavelets are sets of basis functions used in the analysis of signals and \
images.  In contrast to the Fourier trigonometric basis functions (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  "sin and cos), wavelets have both spatial and frequency localisation, \
making them useful for the analysis of sharply-varying or non-periodic \
signals. The (two-scale dilation) equation"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Phi](
        x) = \[Sum]\_\(k = 0\)\%n\( c\_k\) \(\[Phi](
            2  x - k)\)\)\(,\)\)\)], "NumberedEquation",
  CellTags->"two-scale dilation equation"],

Cell["with boundary condition", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Phi](x)\), "=", 
          RowBox[{"0", Cell[" for "], 
            FormBox[\(x \[LessEqual] 0\),
              "TraditionalForm"], Cell[" or "], " ", 
            FormBox[\(x \[GreaterEqual] n\),
              "TraditionalForm"]}]}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"boundary conditions"],

Cell[TextData[{
  "arises in discrete wavelet theory. In this question you will use matrix \
methods and recursion to solve equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-scale dilation equation"],
  ") for the specific case of ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)]],
  "."
}], "Text",
  CellTags->"wavelet theory"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)]],
  ", the boundary condition (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "boundary conditions"],
  ") implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](5) = 0\)]],
  ". Using this and equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-scale dilation equation"],
  "), show that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](i)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3, 4\)]],
  ", satisfy an eigenvalue equation of the form"
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["C",
              FontWeight->"Bold"], ".", 
            RowBox[{"(", GridBox[{
                  {\(\[Phi](1)\)},
                  {\(\[Phi](2)\)},
                  {\(\[Phi](3)\)},
                  {\(\[Phi](4)\)}
                  }], ")"}]}], "=", 
          RowBox[{"(", GridBox[{
                {\(\[Phi](1)\)},
                {\(\[Phi](2)\)},
                {\(\[Phi](3)\)},
                {\(\[Phi](4)\)}
                }], ")"}]}], ","}], TraditionalForm]], "NumberedEquation",
  CellTags->"eigenvalue equation"],

Cell[TextData[{
  "and determine the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["C",
          FontWeight->"Bold"], TraditionalForm]]],
  ". Note that the eigenvalue equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "eigenvalue equation"],
  ") only determines the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](i)\)]],
  " up to a multiplicative constant. ",
  StyleBox["[3]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Applying a set of normalisation, approximation, and orthogonality \
conditions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  ", yields a system of equations for the constants, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  ":"
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[Sum]\_\(k = 0\)\%5 c\_k = 2\)\(,\)\)},
          {\(\(\[Sum]\_\(k = 0\)\%3\( c\_k\) c\_\(k + 2\) = 0\)\(,\)\)},
          {\(\[Sum]\_\(k = 0\)\%1\( c\_k\) c\_\(k + 4\) = 0\)},
          {\(\(\[Sum]\_\(k = 0\)\%5\((\(-1\))\)\^k\ c\_k = 0\)\(,\)\)},
          {\(\(\[Sum]\_\(k = 0\)\%5\(\((\(-1\))\)\^k\) k\ c\_k = 0\)\(,\)\)},
          {\(\[Sum]\_\(k = 0\)\%5\(\((\(-1\))\)\^k\) k\^2\ c\_k = 0. \)}
          }], TraditionalForm]], "NumberedEquation",
  GridBoxOptions->{ColumnAlignments->{"="}},
  CellTags->"coefficient conditions"],

Cell[TextData[{
  "Note that the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  " are non-zero only for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], 5\)]],
  ". Determine the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " values of the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  " by selecting the ",
  StyleBox["real",
    FontSlant->"Italic"],
  " solution to equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "coefficient conditions"],
  ") with largest positive value of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compute the eigenvector of ",
  Cell[BoxData[
      FormBox[
        StyleBox["C",
          FontWeight->"Bold"], TraditionalForm]]],
  " corresponding to unit eigenvalue and impose the normalisation condition, \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%4 \[Phi](i) = 1\)]],
  ", to determine the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](i)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3, 4\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Using the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](i)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, \[Ellipsis], 5\)]],
  ", and the boundary conditions (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "boundary conditions"],
  "), implement the recursive equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-scale dilation equation"],
  ") using dynamic programming. As a check, the exact value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](5\/2)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`5\/208\ \((31 - 10\ \@10)\)\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ".  Compute ",
  StyleBox["approximate ",
    FontSlant->"Italic"],
  "numerical values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\/128, 2\/128, 3\/128, \[Ellipsis], 
      5 - 1\/128\)]],
  ". Use ",
  Cell[BoxData[
      FormBox[
        StyleBox["ListPlot",
          "Input"], TraditionalForm]]],
  " to visualise the solution to equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-scale dilation equation"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega])\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " is defined, as usual, by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega]) = \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[Phi](
              x)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ x\)\) \
\[DifferentialD]x\)]],
  ". Introducing ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH](\[Omega]) = \(1\/2\) \(\[Sum]\+\(k \
= 0\)\%n\( c\_k\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ \[Omega]\)\)\)]],
  ", and given that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[Phi](
              x)\) \[DifferentialD]x = 1\)]],
  ", use equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-scale dilation equation"],
  ") to show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega])\)]],
  " satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega]) = \(\[ScriptCapitalH](\
\[Omega]\/2)\) \(\(\[Phi]\&^\)(\[Omega]\/2)\)\)]],
  " and hence that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega]) = \[Product]\+\(i = 1\)\%\
\[Infinity] \[ScriptCapitalH](\[Omega]\/2\^i)\)]],
  ". ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compute and simplify \[ScriptCapitalH](\[Omega]) for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(\[Phi]\&^\)(\[Omega])\
\[RightBracketingBar]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] \[Element] \([\(-6\) \[Pi], 
          6  \[Pi]]\)\)]],
  " by suitably truncating the infinite product expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)(\[Omega])\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Green Function Solution to an Inverse Problem ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "A powerful and general method for solving inhomogeneous differential \
equations such as ",
  Cell[BoxData[
      \(TraditionalForm\`L[f(x)] = g(x)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is a differential operator with homogenous boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`f(a) = 0, \ f(b) = 0\)]],
  ", is provided by the ",
  StyleBox["Green function",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`G(x, y)\)]],
  ", which formally satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(x, y)] = \[Delta](x - y)\)]],
  ", where \[Delta] is the ",
  StyleBox["Dirac delta function",
    FontSlant->"Italic"],
  " (distribution), and the (homogenous) boundary conditions"
}], "Text",
  CellTags->{"Green function", "Dirac delta function", "distribution"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(G(a, y) = 0, \ G(b, y) = 0, \ G(x, a) = 0, \ 
    G(x, b) = 0. \)\)\)], "NumberedEquation",
  CellTags->"homogenous boundary conditions"],

Cell["\<\
Green functions are due to George Green (1793-1841), an English mathematician \
whose work was not appreciated during his lifetime\[ThinSpace]\[LongDash]\
\[ThinSpace]largely due to his unusual methodology.\
\>", "Text"],

Cell[TextData[{
  "The strength of the method is that ",
  Cell[BoxData[
      \(TraditionalForm\`G(x, y)\)]],
  " is ",
  StyleBox["independent",
    FontSlant->"Italic"],
  " of the inhomogeneous part of the differential equation, ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  ". The solution to the differential equation is"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`f(
        x) = \[Integral]\_a\%b\ \(G(x, y)\) \(g(
            y)\) \(\(\[DifferentialD]y\)\(.\)\)\)], "NumberedEquation",
  CellTags->"solution"],

Cell["\<\
Consider the differential equation describing a forced simple harmonic \
oscillator:\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(\(x\^\[DoublePrime]\)(t) + x(t) = 
      g(t)\)\(,\)\)\)], "NumberedEquation",
  CellTags->"forced simple harmonic oscillator"],

Cell["along with the boundary conditions", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`x(0) = \(x(\[Pi]\/2) = 0. \)\)], "NumberedEquation",
  CellTags->"boundary conditions"],

Cell[TextData[{
  "The (region-dependent) Green function, independent of ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", is"
}], "Text",
  CellTags->"region-dependent function"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{\(G(t, \[Tau])\), "=", 
          RowBox[{
            RowBox[{
              StyleBox["{",
                SpanMaxSize->Infinity], GridBox[{
                  {\(\(-cos\) \((\[Tau])\)\ \(sin(t)\), \ 
                    0 \[LessEqual] 
                      t \[LessEqual] \[Tau] \[LessEqual] \[Pi]\/2\)},
                  {\(\(-cos\) \((t)\)\ \(sin(\[Tau])\), \ 
                    0 \[LessEqual] \[Tau] \[LessEqual] 
                      t \[LessEqual] \[Pi]\/2\)}
                  }], "\[AutoRightMatch]"}], "."}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Implement the Green function. Show that it is continuous. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Verify that the Green function satisfies the homogenous boundary \
conditions (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "homogenous boundary conditions"],
  ") and the homogenous differential equation, ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(t, \[Tau])] \[Equal] 0\)]],
  ", in each region (",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t < \[Tau] \[LessEqual] \[Pi]\/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \[Tau] < t \[LessEqual] \[Pi]\/2\)]],
  "). ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Visualize the Green function to reveal its behaviour on the boundaries \
and determine its symmetry about the diagonal line ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau]\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The Green function has a discontinuous derivative along the line ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau]\)]],
  ". Compute the difference in the derivative across this line. \
Differentiation of this step-function discontinuity leads to the Dirac delta \
function (distribution), ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(t, \[Tau])] = \[Delta](t - \[Tau])\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"discontinuous derivative"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For the forcing term ",
  Cell[BoxData[
      \(TraditionalForm\`g(t) = \[ExponentialE]\^t\ \(sin(10\ t)\)\)]],
  " compute the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " solution, ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", to the differential equation using the Green function and equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "solution"],
  "). Verify that your solution ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is correct (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", it satisfies (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "forced simple harmonic oscillator"],
  ") and takes into account the boundary conditions). ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"exact solution"],

Cell[CellGroupData[{

Cell[TextData[{
  "Consider the ",
  StyleBox["inverse problem",
    FontSlant->"Italic"],
  " of determining the Inhomogeneous part, ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", of the differential equation by measuring ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " at a finite number of times. Discretizing the equation, we obtain the \
following matrix equation:"
}], "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{"discretizing equations", "inverse problem"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(x(
        t) = \(\[Integral]\_0\%\(\[Pi]/2\)\ \(G(
              t, \[Tau])\) \(g(\[Tau])\) \[DifferentialD]\[Tau]\
\[LongRightArrow]\(x(t\_i)\) = \(\[Sum]\+\(j = 0\)\%m\ \(G(
                t\_i, \[Tau]\_j)\) \(g(\[Tau]\_j)\) \[Delta]\[Tau]\_j\
\[LongRightArrow]x\_i = \[Sum]\+j\( G\_\(i\[InvisibleComma]j\)\) 
              g\_j\)\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\) = \(G(
            t\_i, \[Tau]\_j)\) \[Delta]\[Tau]\_j\)]],
  ". The discretized forcing term ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j \[Congruent] g(\[Tau]\_j)\)]],
  " can be computed from the inverse of the (discretized) Green function,"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`x\_i = \(\[Sum]\+j\( G\_\(i\[InvisibleComma]j\)\) 
              g\_j \[Implies] 
          g\_j = \[Sum]\+i\( G\_\(i\[InvisibleComma]j\)\^\(-1\)\) \
\(\(x\_i\)\(\[CenterDot]\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "For a list of",
  StyleBox[" equally-spaced",
    FontSlant->"Italic"],
  " data points, this discretization corresponds to the ",
  StyleBox["trapezoid approximation",
    FontSlant->"Italic"],
  " because the Green function vanishes along the boundaries. "
}], "Warning",
  CellTags->{"equally spaced data points", "trapezoid approximation"}],

Cell[TextData[{
  "Note that, in general, the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\)\)]],
  " is ",
  StyleBox["rectangular",
    FontSlant->"Italic"],
  " because there can be a ",
  StyleBox["different",
    FontSlant->"Italic"],
  " number of ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_j\)]],
  " samples. Hence no inverse matrix exists in the usual sense. However, \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j = g(\[Tau]\_j)\)]],
  " can be computed using the pseudo- or Moore-Penrose inverse (",
  Cell[BoxData[
      FormBox[
        StyleBox["PseudoInverse",
          "Input"], TraditionalForm]]],
  ")."
}], "Text",
  CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Suppose that, at the times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i = 
        0, \[Pi]\/30, \(2  \[Pi]\)\/30, \[Ellipsis], \[Pi]\/2\)]],
  ", we make measurements of the displacements ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i = x(t\_i)\)]],
  ". Using the exact solution found in question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "exact solution"],
  ", the displacements at these times can be computed. Compute the driving \
term, ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j = g(\[Tau]\_j)\)]],
  ", at the times ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_j = 
        0, \[Pi]\/40, \(2  \[Pi]\)\/40, \[Ellipsis], \[Pi]\/2\)]],
  ", by (matrix) multiplying the pseudo-inverse of the discretized product ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\)\)]],
  " with the ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  ". ",
  StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compare the forcing term, ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", and the discretized (inverse) solution, ",
  Cell[BoxData[
      \(TraditionalForm\`g(\[Tau]\_j)\)]],
  ", and comment. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Maxwell Construction ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "The equation of state of an ideal gas of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\)]],
  " noninteracting classical particles reads"
}], "Text",
  CellTags->{"equation of state", "ideal gas"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(p\ V \[Equal] \[ScriptCapitalN]\ \(k\_B\) 
        T\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  " is the Boltzmann constant. A simple approximation, taking into account \
the interaction between particles, is the van der Waals equation of state,"
}], "Text",
  CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(\((p + a\/V\^2)\) \((V - 
            b)\) \[Equal] \[ScriptCapitalN]\ \(k\_B\) 
        T\)\(,\)\)\)], "NumberedEquation",
  CellTags->"van der Waals"],

Cell[TextData[{
  "with parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ".  As you will see, there exists a critical temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  " below which loops appear in the ",
  Cell[BoxData[
      \(TraditionalForm\`p - V\)]],
  " diagram.  These loops are forbidden for thermodynamical reasons. For ",
  Cell[BoxData[
      \(TraditionalForm\`T < T\_c\)]],
  ", a phase transition between gas and liquid takes place; at ",
  Cell[BoxData[
      \(TraditionalForm\`T = T\_c\)]],
  " the difference between the liquid and gaseous phases vanishes."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  " are determined by the condition that the first and second derivatives of \
",
  Cell[BoxData[
      \(TraditionalForm\`p(V, T)\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " vanish, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(p(V, T)\)\), \(\[PartialD]V\),
            MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( p(V, T)\)\), \(\[PartialD]V\^2\),
            MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
  ". "
}], "Text"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and the corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c = p(V\_c, T\_c)\)]],
  " for the van der Waals equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "van der Waals"],
  "). As a check, you should find that ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c = a\/\(27\ b\^2\)\)]],
  ". ",
  StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Rescale ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", respectively, to obtain a dimensionless form of the van der Waals \
equation. In the following, the dimensionless parameters are denoted using ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~ = x/x\_c\)]],
  ". ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Plot a set of ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~ - V\&~\)]],
  " curves for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", 
          "1.05"}], TraditionalForm]]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`0.5 \[LessEqual] V\&~ \[LessEqual] 5\)]],
  " to visualise the unphysical van der Waals loops which arise for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\&~\), "<", 
          StyleBox["1",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], TraditionalForm]]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  "Over a certain temperature range, three volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v\_2 \[LessEqual] v\_3\)]],
  " correspond to each pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~\)]],
  ".  For thermodynamic reasons, the transition from the gas with large \
volume ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ", to the liquid, with small volume ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", takes place at the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~\)]],
  " for which "
}], "Text",
  CellGroupingRules->{"SectionGrouping", 45}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(v\_1\%v\_3\)\(\(p\&~\)(
            v)\) \[DifferentialD]v = \((v\_3 - 
            v\_1)\) \(\(\(p\_t\)\&~\)\(\[CenterDot]\)\)\)], "NumberedEquation",\

  CellTags->"equal area"],

Cell[TextData[{
  "At ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~\)]],
  ", gas and liquid are simultaneously present for all volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_3\)]],
  "; one observes a two-phase mixture.  Geometrically, equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "equal area"],
  ") means that the area between the curve ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\&~\)(v)\)]],
  " and the straight line ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~ = constant\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_2\)]],
  " is the same as the corresponding area for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2 \[LessEqual] v \[LessEqual] v\_3\)]],
  ". This is known as the ",
  StyleBox["Maxwell construction",
    FontSlant->"Italic"],
  ".We want to construct the line ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~ = constant\)]],
  ", the two-phase line. For the two-phase line we need two equations in \
order to determine the two unknown volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ":"
}], "Text",
  CellTags->{"two-phase line", "Maxwell construction"}]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(p\&~\)(v\_1, t)\), 
            "\[Equal]", \(\(\(p\&~\)(v\_3, t)\)\(,\)\)},
          {\(\[Integral]\_\(v\_1\%v\_3\)\(\(p\&~\)(v, 
                  t)\) \[DifferentialD]v\), 
            "\[Equal]", \(\((v\_3 - v\_1)\) \(\(\(p\&~\)(v\_1, t)\)\(.\)\)\)}
          }], TraditionalForm]], "NumberedEquation",
  CellTags->"two-phase"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". There is no simple analytical solution to equations (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-phase"],
  ") so, for each temperature, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], 
        TraditionalForm]]],
  ", determine ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  " using ",
  Cell[BoxData[
      FormBox[
        StyleBox["FindRoot",
          "Input"], TraditionalForm]]],
  ". You will need fairly accurate initial guesses \[LongDash] these can be \
obtained from the plots of the unphysical van der Waals ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~ - V\&~\)]],
  " equation in part [c]. ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Display the Maxwell construction for the van der Waals equation for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", 
          "1.05"}], TraditionalForm]]],
  ". Physically interpret the lowest three curves (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], 
        TraditionalForm]]],
  ") and the two-phase lines. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Normal Modes of a Circular Membrane ",
  StyleBox["[20]", "Marks"]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
If there is no external force, the wave equation for free vibrations of a \
uniform isotropic membrane reads\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( u(x, y, t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], 
          "=", \(c\^2\ \[CapitalDelta]\ \(u(x, y, t)\)\)}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"wave equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  " is the two-dimensional Laplacian operator,"
}], "Text",
  CellTags->{"boundary condition", "polar coordinates"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[CapitalDelta] = \[PartialD]\^2\/\[PartialD]x\^2 + \(\
\(\[PartialD]\^2\/\[PartialD]y\^2\)\(.\)\)\)], "NumberedEquation",
  CellTags->"Laplacian"],

Cell[TextData[{
  "For a circular membrane of radius ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  " fixed at its edge, polar coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " are convenient; the boundary condition is ",
  Cell[BoxData[
      \(TraditionalForm\`u(1, \[Theta], t) = 0\)]],
  " and the Laplacian",
  " (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Laplacian"],
  ") ",
  "reads"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[CapitalDelta][
        f_] := \(1\/r\) \[PartialD]\((r \[PartialD]f\/\[PartialD]r)\)\/\
\[PartialD]r + \(1\/r\^2\) \[PartialD]\^2 f\/\[PartialD]\[Theta]\^2\)], \
"Input"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "By hand, or using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", apply separation of variables, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta], 
          t) = \(R(
            r)\)\ \(\[CapitalTheta](\[Theta])\)\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Omega]\ t\)\)]],
  ", and introduce a ",
  StyleBox["separation constant",
    FontSlant->"Italic"],
  ", to reduce equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "wave equation"],
  ") to a pair of ordinary differential equations. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"separation of variables"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Solve the differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\)]],
  ". What condition does this solution place on the separation constant?  ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": a physical solution must be single-valued, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta] + 
            2  m\ \[Pi]) = \[CapitalTheta](\[Theta])\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "\[Element]", 
          FormBox[
            TagBox["\[DoubleStruckCapitalZ]",
              (Integers&)],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Hence, choose the separation constant so that you will get trigonometric \
solutions to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\)]],
  "-equation. ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine the differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", eliminating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " using ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2 = \[Omega]\^2/c\^2\)]],
  ", and solve this equation (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you should obtain a solution involving a pair of Bessel functions.) \
Produce plots of the linearly independent solutions for a range of values of \
the separation constant. ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Considering the nature of the solution at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", one of the linearly independent solutions can be excluded. Hence write \
down the general solution to equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "wave equation"],
  "). ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Apply the boundary condition, ",
  Cell[BoxData[
      \(TraditionalForm\`u(1, \[Theta], t) = 0\)]],
  ", to write down an expression which ",
  StyleBox["implicitly",
    FontSlant->"Italic"],
  " determines the allowed values of ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(\[Omega]/c = 2  \[Pi]\ \[Nu]/\ c\)\)]],
  ". Determine the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-values corresponding to the 10 lowest frequencies and, in one plot, \
display the corresponding (unnormalised) radial functions ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\)]],
  ". ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you may find the ",
  Cell[BoxData[
      FormBox[
        StyleBox["NumericalMath`BesselZeros`",
          "Input"], TraditionalForm]]],
  " package or the ",
  Cell[BoxData[
      FormBox[
        StyleBox["RootsInRange",
          "Input"], TraditionalForm]]],
  " function (loaded when you start the kernel) useful. ",
  StyleBox["[8]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Produce an animation of one period (",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]/\[Omega]\)]],
  ") of ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta], t)\)]],
  " for the third lowest frequency. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you may find ",
  Cell[BoxData[
      FormBox[
        StyleBox["CylindricalPlot3D",
          "Input"], TraditionalForm]]],
  " useful. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Matrix Arithmetic ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "The ",
  StyleBox["Pauli spin matrices",
    FontSlant->"Italic"],
  ", "
}], "Text",
  CellTags->"Pauli spin matrices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_1\), "=", 
          RowBox[{"(", GridBox[{
                {"0", "1"},
                {"1", "0"}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_2\), "=", 
          RowBox[{"(", GridBox[{
                {"0", \(-\[ImaginaryI]\)},
                {"\[ImaginaryI]", "0"}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_3\), "=", 
          RowBox[{"(", GridBox[{
                {"1", "0"},
                {"0", \(-1\)}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "along with the ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Cross]2\)]],
  " identity matrix:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalI]\_n_ := IdentityMatrix[n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalI]\_2\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {"0", "1"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
are used in a matrix representation of spin operators in quantum mechanics.\
\>", "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i . \[Sigma]\_i = \
\[ScriptCapitalI]\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Introducing the ",
  StyleBox["commutator bracket",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\) = a . b - b . a\)]],
  ", verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\([\[Sigma]\_i, \[Sigma]\_j]\) = 
        2  \[ImaginaryI]\ \(\[Epsilon]\_\(i, j, k\)\) \[Sigma]\_k\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_\(i, j, k\)\)]],
  " is the (3-component) Levi-Civita tensor which is ",
  Cell[BoxData[
      \(TraditionalForm\`\(+1\)\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j, k)\)\)]],
  " is a cyclic permutation of the indices, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j, k)\)\)]],
  " is an anti-cyclic permutation, and ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " otherwise. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": there is a very simple and general implementation of this tensor, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Epsilon]\_i__ := Signature[{i}]\),
          "Input"], TraditionalForm]]],
  ". Also, you might find ",
  Cell[BoxData[
      FormBox[
        StyleBox["Permutations",
          "Input"], TraditionalForm]]],
  " useful. ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"Levi-Civita tensor"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Show that the three matrices, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3\)]],
  ", along with unit ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalI]\_2\)]],
  " form a complete set of ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrices in the sense that an ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " complex ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrix can be expressed in terms of them. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["A",
                  FontWeight->"Bold"]}], ")"}], 
            RowBox[{"(", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["B",
                  FontWeight->"Bold"]}], ")"}]}], "=", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "\[CenterDot]", 
              StyleBox["B",
                FontWeight->"Bold"]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["A",
                      FontWeight->"Bold"], "\[Cross]", 
                    StyleBox["B",
                      FontWeight->"Bold"]}], ")"}]}]}]}]}], 
        TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Sigma]",
            FontWeight->"Bold"], 
          StyleBox["\[Congruent]",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{
              TagBox[\(\[Sigma]\_1\),
                HoldForm], ",", 
              TagBox[\(\[Sigma]\_2\),
                HoldForm], ",", 
              TagBox[\(\[Sigma]\_3\),
                HoldForm]}], ")"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["A",
          FontWeight->"Bold"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["B",
          FontWeight->"Bold"], TraditionalForm]]],
  " are any two vectors. ",
  StyleBox["NB",
    FontSlant->"Italic"],
  ": this identity, as stated, is a typical abuse of notation widely used in \
quantum mechanics texts.  Explicitly, what you are trying to show is that "
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\((\(a\_1\) \[Sigma]\_1 + \(a\_2\) \[Sigma]\_2 + \(a\_3\) \
\[Sigma]\_3)\) . \((\(b\_1\) \[Sigma]\_1 + \(b\_2\) \[Sigma]\_2 + \(b\_3\) \
\[Sigma]\_3)\)\), "\[Equal]", 
        RowBox[{\({a\_1, a\_2, a\_3} . {b\_1, b\_2, 
                b\_3} \[ScriptCapitalI]\_2\), "+", 
          RowBox[{"\[ImaginaryI]", " ", 
            
            RowBox[{\(({a\_1, a\_2, a\_3}\[Cross]{b\_1, b\_2, b\_3})\), 
              ".", \({\[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}\), ".", " ", 
              StyleBox[\([3]\),
                "Marks"]}]}]}]}], TraditionalForm]], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The following set of 5, ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Times]4\)]],
  ", ",
  StyleBox["Dirac gamma matrices",
    FontSlant->"Italic"],
  " arise in relativistic quantum mechanics:"
}], "BeginQuestion",
  CellTags->"Dirac gamma matrices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Gamma]\_k\), "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\[ScriptCapitalO]", \(\(-\[ImaginaryI]\)\ \[Sigma]\_k\)},
                {\(\[ImaginaryI]\ \[Sigma]\_k\), "\[ScriptCapitalO]"}
                }], "\[NoBreak]", ")"}]}], ",", " ", \(k = 1\), ",", "2", ",",
         "3", ",", "\[IndentingNewLine]", 
        RowBox[{\(\[Gamma]\_4\), "=", 
          RowBox[{"(", GridBox[{
                {\(\[ScriptCapitalI]\_2\), "\[ScriptCapitalO]"},
                {"\[ScriptCapitalO]", \(-\[ScriptCapitalI]\_2\)}
                }], ")"}]}], ",", 
        "\[IndentingNewLine]", \(\[Gamma]\_5 = \ \[Gamma]\_1 . \[Gamma]\_2 . \
\[Gamma]\_3 . \[Gamma]\_4\), ","}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalO]\)]],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " zero matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalI]\_2\)]],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " unit matrix, and the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_k\)]],
  " are the Pauli spin matrices. Implement these matrices and show that they \
satisfy the following ",
  StyleBox["anti-commutation",
    FontSlant->"Italic"],
  " relation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_\[Mu] . \[Gamma]\_\[Nu] + \[Gamma]\_\[Nu] . \
\[Gamma]\_\[Mu]\), "=", 
          RowBox[{"2", 
            SubscriptBox[
              InterpretationBox["\[Delta]",
                KroneckerDelta,
                Editable->False,
                Selectable->False], \(\[Mu], \[Nu]\)], 
            " ", \(\[ScriptCapitalI]\_4\)}]}], TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu], \[Nu] = 1, 2, 3, 4\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          InterpretationBox["\[Delta]",
            KroneckerDelta,
            Editable->False,
            Selectable->False], \(\[Mu], \[Nu]\)], TraditionalForm]]],
  " is the Kronecker delta function. ",
  StyleBox["[4]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(\[Mu], \[Nu]\) = \(\(1\/\(2\ \
\[ImaginaryI]\)\)[\[Gamma]\_\[Mu], \[Gamma]\_\[Nu]] = \ \(-\[ImaginaryI]\)\ \
\[Gamma]\_\[Mu] . \[Gamma]\_\[Nu]\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[NotEqual] \[Nu] = 1, 2, 3, 4\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(\[Mu] = 1\)\%4 \[Gamma]\_\[Mu] . \((\
\[Gamma] . \[ScriptCapitalA])\) . \((\[Gamma] . \[ScriptCapitalB])\) . \((\
\[Gamma] . \[ScriptCapitalC])\) . \[Gamma]\_\[Mu] = \(-2\) \((\[Gamma] . \
\[ScriptCapitalC])\) . \((\[Gamma] . \[ScriptCapitalB])\) . \((\[Gamma] . \
\[ScriptCapitalA])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Tr(\[Gamma]\_5 . \((\[Gamma] . \[ScriptCapitalA])\) \
. \((\[Gamma] . \[ScriptCapitalB])\)) = 0\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", "=", 
          RowBox[{"(", 
            RowBox[{
              TagBox[\(\[Gamma]\_1\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_2\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_3\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_4\),
                HoldForm]}], ")"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\)]],
  " are ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " 4-vectors, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] = {a\_1, a\_2, a\_3, a\_4}\)]],
  ", ",
  StyleBox["etc",
    FontSlant->"Italic"],
  "., and ",
  Cell[BoxData[
      \(TraditionalForm\`Tr\)]],
  " denotes the trace of a square matrix (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the sum of the diagonal entries in the matrix).  ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{956, 647},
WindowMargins->{{8, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{3, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{Cell[ 
        TextData[ {"Computational Physics ", 
          CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
    Inherited, Inherited, Cell[ 
        TextData[ {"Computational Physics ", 
          CounterBox[ "Page"]}], "Footer"]}},
PageHeaderLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{18, 18}, {36, 36}},
"FirstPageHeader"->False,
"FacingPages"->True},
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"], 
    "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Inherited, Inherited, Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"]}},
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title resets all cell \
CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {30, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, Subtitle states \
topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading in a \
notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"Equation", 0}, {"Exercise", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. Sets counter \
values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "Equation", 0}, {"Exercise", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    PageBreakAbove->True,
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Open  ]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellDingbat->None,
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a subsection \
level heading directly follows a section level heading. Sets counter \
Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 10}, {Inherited, 0}},
    TextJustification->1,
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 10}, {Inherited, 0}},
    TextJustification->1,
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by either \
Question or Input/Output etc. Last paragraph of the question should be in \
EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{54, 10}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 58},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{54, 10}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after a section \
cell. Used if the question is a single text paragraph.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{54, 10}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or BeginEndQuestion cell \
style to begin the answer portion. Followed by Text or Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{54, 10}, {Inherited, Inherited}},
    TextJustification->1,
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published elsewhere (and \
appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{80, 20}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input cell, not \
followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{120, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None,
    Magnification->0.8],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Open  ]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell has \
ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells embedded within \
another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want to number \
sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellGroupingRules->{"SectionGrouping", 59},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Figure \
and the NumberedFigure counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellMargins->{{144, Inherited}, {Inherited, Inherited}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Open  ]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Table and \
the NumberedTable counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Listing \
and the NumberedProgram counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of FilledSmallCircle. \
Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list sequence. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the List \
counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list sequence with \
a single digit. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered list sequence \
with two digits. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a notebook. One \
cell for each bibliography entry. Use the TMJAuthorPalette.nb palette to \
begin cell and paste in the Reference counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes the Title \
cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). Author name(s) \
may be preced by \"Edited by \" for certain columns. Text in author cell to \
be used as the left page header. Usually followed by an Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact information \
for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {30, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short descriptive \
summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with the Help \
Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Marks"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    FontFamily->"Times",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Marks", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Marks", "Printout"]]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed tabular material. \
Can be followed by NumberedTableCaption cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"],
    TextJustification->1,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other cells.  If the \
FormatType of a cell style matches the name of one of the styles defined \
below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Equal"->{
    Cell[5790, 190, 363, 13, 70, "Text",
      CellTags->{"Equal", "Listable"}]},
  "Listable"->{
    Cell[5790, 190, 363, 13, 70, "Text",
      CellTags->{"Equal", "Listable"}]},
  "pulsar PSR1257+12"->{
    Cell[9739, 311, 742, 20, 70, "Text",
      CellTags->"pulsar PSR1257+12"]},
  "timing residuals"->{
    Cell[11085, 344, 935, 23, 70, "Text",
      CellTags->{"timing residuals", "Alex Wolszczan"}]},
  "Alex Wolszczan"->{
    Cell[11085, 344, 935, 23, 70, "Text",
      CellTags->{"timing residuals", "Alex Wolszczan"}]},
  "residuals"->{
    Cell[13027, 415, 226, 10, 70, "BeginEndQuestion",
      CellTags->"residuals"]},
  "Fourier"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "astronomical time-series data"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "spectral analysis"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "irregularly sampled data"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "interpolation"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "resampling"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "linear least-squares"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "spectral energy"->{
    Cell[13256, 427, 1886, 57, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{
      "Fourier", "astronomical time-series data", "spectral analysis", 
        "irregularly sampled data", "interpolation", "resampling", 
        "linear least-squares", "spectral energy"}]},
  "two-scale dilation equation"->{
    Cell[19478, 660, 201, 4, 70, "NumberedEquation",
      CellTags->"two-scale dilation equation"]},
  "boundary conditions"->{
    Cell[19758, 671, 384, 10, 70, "NumberedEquation",
      CellTags->"boundary conditions"],
    Cell[30705, 1092, 124, 2, 70, "NumberedEquation",
      CellTags->"boundary conditions"]},
  "wavelet theory"->{
    Cell[20145, 683, 364, 13, 70, "Text",
      CellTags->"wavelet theory"]},
  "eigenvalue equation"->{
    Cell[21312, 737, 629, 19, 70, "NumberedEquation",
      CellTags->"eigenvalue equation"]},
  "coefficient conditions"->{
    Cell[22803, 796, 587, 10, 70, "NumberedEquation",
      CellTags->"coefficient conditions"]},
  "Green function"->{
    Cell[28424, 1012, 860, 25, 70, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "Dirac delta function"->{
    Cell[28424, 1012, 860, 25, 70, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "distribution"->{
    Cell[28424, 1012, 860, 25, 70, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "homogenous boundary conditions"->{
    Cell[29309, 1041, 184, 3, 70, "NumberedEquation",
      CellTags->"homogenous boundary conditions"]},
  "solution"->{
    Cell[30115, 1068, 184, 4, 70, "NumberedEquation",
      CellTags->"solution"]},
  "forced simple harmonic oscillator"->{
    Cell[30447, 1082, 168, 3, 70, "NumberedEquation",
      CellTags->"forced simple harmonic oscillator"]},
  "region-dependent function"->{
    Cell[30832, 1096, 188, 6, 70, "Text",
      CellTags->"region-dependent function"]},
  "discontinuous derivative"->{
    Cell[32881, 1173, 619, 20, 70, "BeginEndQuestion",
      CellTags->"discontinuous derivative"]},
  "exact solution"->{
    Cell[33503, 1195, 892, 36, 70, "BeginEndQuestion",
      CellTags->"exact solution"]},
  "discretizing equations"->{
    Cell[34420, 1235, 509, 14, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{"discretizing equations", "inverse problem"}]},
  "inverse problem"->{
    Cell[34420, 1235, 509, 14, 70, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{"discretizing equations", "inverse problem"}]},
  "equally spaced data points"->{
    Cell[36005, 1282, 363, 9, 70, "Warning",
      CellTags->{"equally spaced data points", "trapezoid approximation"}]},
  "trapezoid approximation"->{
    Cell[36005, 1282, 363, 9, 70, "Warning",
      CellTags->{"equally spaced data points", "trapezoid approximation"}]},
  "Moore-Penrose inverse"->{
    Cell[36371, 1293, 806, 27, 70, "Text",
      CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]},
  "PseudoInverse"->{
    Cell[36371, 1293, 806, 27, 70, "Text",
      CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]},
  "equation of state"->{
    Cell[38750, 1387, 232, 6, 70, "Text",
      CellTags->{"equation of state", "ideal gas"}]},
  "ideal gas"->{
    Cell[38750, 1387, 232, 6, 70, "Text",
      CellTags->{"equation of state", "ideal gas"}]},
  "Boltzmann constant"->{
    Cell[39136, 1401, 305, 7, 70, "Text",
      CellTags->{"Boltzmann constant", "van der Waals equation"}]},
  "van der Waals equation"->{
    Cell[39136, 1401, 305, 7, 70, "Text",
      CellTags->{"Boltzmann constant", "van der Waals equation"}]},
  "van der Waals"->{
    Cell[39478, 1413, 193, 4, 70, "NumberedEquation",
      CellTags->"van der Waals"]},
  "equal area"->{
    Cell[44045, 1590, 231, 5, 70, "NumberedEquation",
      CellTags->"equal area"]},
  "two-phase line"->{
    Cell[44279, 1597, 1372, 43, 70, "Text",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "Maxwell construction"->{
    Cell[44279, 1597, 1372, 43, 70, "Text",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "two-phase"->{
    Cell[45666, 1643, 383, 8, 70, "NumberedEquation",
      CellTags->"two-phase"]},
  "wave equation"->{
    Cell[48316, 1744, 317, 8, 70, "NumberedEquation",
      CellTags->"wave equation"]},
  "boundary condition"->{
    Cell[48636, 1754, 206, 6, 70, "Text",
      CellTags->{"boundary condition", "polar coordinates"}]},
  "polar coordinates"->{
    Cell[48636, 1754, 206, 6, 70, "Text",
      CellTags->{"boundary condition", "polar coordinates"}]},
  "Laplacian"->{
    Cell[48879, 1765, 184, 3, 70, "NumberedEquation",
      CellTags->"Laplacian"]},
  "separation of variables"->{
    Cell[49764, 1798, 773, 31, 70, "BeginEndQuestion",
      CellTags->"separation of variables"]},
  "Pauli spin matrices"->{
    Cell[54422, 1983, 139, 6, 70, "Text",
      CellTags->"Pauli spin matrices"]},
  "Levi-Civita tensor"->{
    Cell[56498, 2071, 1428, 50, 70, "BeginEndQuestion",
      CellTags->"Levi-Civita tensor"]},
  "Dirac gamma matrices"->{
    Cell[61566, 2247, 340, 14, 70, "BeginQuestion",
      CellTags->"Dirac gamma matrices"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Equal", 134692, 4806},
  {"Listable", 134790, 4809},
  {"pulsar PSR1257+12", 134897, 4812},
  {"timing residuals", 135001, 4815},
  {"Alex Wolszczan", 135123, 4818},
  {"residuals", 135240, 4821},
  {"Fourier", 135340, 4824},
  {"astronomical time-series data", 135682, 4831},
  {"spectral analysis", 136012, 4838},
  {"irregularly sampled data", 136349, 4845},
  {"interpolation", 136675, 4852},
  {"resampling", 136998, 4859},
  {"linear least-squares", 137331, 4866},
  {"spectral energy", 137659, 4873},
  {"two-scale dilation equation", 137999, 4880},
  {"boundary conditions", 138128, 4883},
  {"wavelet theory", 138339, 4888},
  {"eigenvalue equation", 138444, 4891},
  {"coefficient conditions", 138569, 4894},
  {"Green function", 138689, 4897},
  {"Dirac delta function", 138838, 4900},
  {"distribution", 138979, 4903},
  {"homogenous boundary conditions", 139138, 4906},
  {"solution", 139260, 4909},
  {"forced simple harmonic oscillator", 139385, 4912},
  {"region-dependent function", 139527, 4915},
  {"discontinuous derivative", 139648, 4918},
  {"exact solution", 139771, 4921},
  {"discretizing equations", 139892, 4924},
  {"inverse problem", 140073, 4928},
  {"equally spaced data points", 140265, 4932},
  {"trapezoid approximation", 140418, 4935},
  {"Moore-Penrose inverse", 140569, 4938},
  {"PseudoInverse", 140695, 4941},
  {"equation of state", 140825, 4944},
  {"ideal gas", 140938, 4947},
  {"Boltzmann constant", 141060, 4950},
  {"van der Waals equation", 141200, 4953},
  {"van der Waals", 141331, 4956},
  {"equal area", 141438, 4959},
  {"two-phase line", 141546, 4962},
  {"Maxwell construction", 141680, 4965},
  {"two-phase", 141803, 4968},
  {"wave equation", 141909, 4971},
  {"boundary condition", 142024, 4974},
  {"polar coordinates", 142154, 4977},
  {"Laplacian", 142276, 4980},
  {"separation of variables", 142392, 4983},
  {"Pauli spin matrices", 142519, 4986},
  {"Levi-Civita tensor", 142628, 4989},
  {"Dirac gamma matrices", 142752, 4992}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 45, 0, 31, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1824, 55, 26, 0, 100, "Title"],
Cell[1853, 57, 391, 10, 143, "Address"],

Cell[CellGroupData[{
Cell[2269, 71, 34, 0, 68, "Subsection"],
Cell[2306, 73, 125, 3, 70, "Text"],
Cell[2434, 78, 443, 13, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2914, 96, 32, 0, 39, "Subsection"],
Cell[2949, 98, 134, 5, 70, "Text"],
Cell[3086, 105, 465, 7, 70, "Quote"],
Cell[3554, 114, 404, 6, 70, "Quote"],
Cell[3961, 122, 481, 9, 70, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[4479, 136, 46, 0, 39, "Subsection"],
Cell[4528, 138, 383, 12, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4948, 155, 36, 0, 39, "Subsection"],
Cell[4987, 157, 130, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[5142, 164, 33, 0, 70, "Subsubsection"],
Cell[5178, 166, 215, 5, 70, "Text"],
Cell[5396, 173, 112, 2, 70, "Input",
  InitializationCell->True],
Cell[5511, 177, 85, 2, 70, "Text"],
Cell[5599, 181, 117, 2, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5753, 188, 34, 0, 70, "Subsubsection"],
Cell[5790, 190, 363, 13, 70, "Text",
  CellTags->{"Equal", "Listable"}],
Cell[6156, 205, 99, 2, 70, "Input",
  InitializationCell->True],
Cell[6258, 209, 134, 3, 70, "Input",
  InitializationCell->True],
Cell[6395, 214, 225, 5, 70, "Input",
  InitializationCell->True],
Cell[6623, 221, 97, 2, 70, "Input",
  InitializationCell->True],
Cell[6723, 225, 58, 0, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6818, 230, 39, 0, 70, "Subsubsection"],
Cell[6860, 232, 115, 2, 70, "Input",
  InitializationCell->True],
Cell[6978, 236, 737, 13, 70, "Input",
  InitializationCell->True],
Cell[7718, 251, 280, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8035, 262, 52, 0, 70, "Subsubsection"],
Cell[8090, 264, 140, 3, 70, "Input",
  InitializationCell->True],
Cell[8233, 269, 157, 4, 70, "Input",
  InitializationCell->True],
Cell[8393, 275, 63, 0, 70, "Text"],
Cell[8459, 277, 247, 4, 70, "Input",
  InitializationCell->True],
Cell[8709, 283, 848, 15, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9606, 304, 130, 5, 50, "SectionFirst"],
Cell[9739, 311, 742, 20, 70, "Text",
  CellTags->"pulsar PSR1257+12"],
Cell[10484, 333, 598, 9, 70, "Text"],
Cell[11085, 344, 935, 23, 70, "Text",
  CellTags->{"timing residuals", "Alex Wolszczan"}],
Cell[12023, 369, 292, 13, 70, "BeginEndQuestion"],
Cell[12318, 384, 706, 29, 70, "BeginEndQuestion"],
Cell[13027, 415, 226, 10, 70, "BeginEndQuestion",
  CellTags->"residuals"],
Cell[13256, 427, 1886, 57, 70, "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{
  "Fourier", "astronomical time-series data", "spectral analysis", 
    "irregularly sampled data", "interpolation", "resampling", 
    "linear least-squares", "spectral energy"}],
Cell[15145, 486, 433, 16, 70, "BeginEndQuestion"],
Cell[15581, 504, 434, 19, 70, "BeginEndQuestion"],
Cell[16018, 525, 388, 12, 70, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[16431, 541, 225, 8, 70, "BeginQuestion"],
Cell[16659, 551, 239, 4, 70, "Input"],
Cell[16901, 557, 1978, 77, 70, "EndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[18928, 640, 103, 5, 48, "Section"],
Cell[19034, 647, 419, 9, 70, "Text"],

Cell[CellGroupData[{
Cell[19478, 660, 201, 4, 70, "NumberedEquation",
  CellTags->"two-scale dilation equation"],
Cell[19682, 666, 39, 0, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19758, 671, 384, 10, 70, "NumberedEquation",
  CellTags->"boundary conditions"],
Cell[20145, 683, 364, 13, 70, "Text",
  CellTags->"wavelet theory"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20546, 701, 763, 34, 70, "BeginQuestion"],
Cell[21312, 737, 629, 19, 70, "NumberedEquation",
  CellTags->"eigenvalue equation"],
Cell[21944, 758, 460, 17, 70, "EndQuestion"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22441, 780, 359, 14, 70, "BeginQuestion"],
Cell[22803, 796, 587, 10, 70, "NumberedEquation",
  CellTags->"coefficient conditions"],
Cell[23393, 808, 658, 27, 70, "EndQuestion"]
}, Open  ]],
Cell[24066, 838, 593, 23, 70, "BeginEndQuestion"],
Cell[24662, 863, 775, 32, 70, "BeginEndQuestion"],
Cell[25440, 897, 724, 32, 70, "BeginEndQuestion"],
Cell[26167, 931, 1446, 45, 70, "BeginEndQuestion"],
Cell[27616, 978, 628, 22, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[28281, 1005, 140, 5, 48, "Section"],
Cell[28424, 1012, 860, 25, 70, "Text",
  CellTags->{"Green function", "Dirac delta function", "distribution"}],

Cell[CellGroupData[{
Cell[29309, 1041, 184, 3, 70, "NumberedEquation",
  CellTags->"homogenous boundary conditions"],
Cell[29496, 1046, 230, 4, 70, "Text"],
Cell[29729, 1052, 349, 11, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30115, 1068, 184, 4, 70, "NumberedEquation",
  CellTags->"solution"],
Cell[30302, 1074, 108, 3, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30447, 1082, 168, 3, 70, "NumberedEquation",
  CellTags->"forced simple harmonic oscillator"],
Cell[30618, 1087, 50, 0, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30705, 1092, 124, 2, 70, "NumberedEquation",
  CellTags->"boundary conditions"],
Cell[30832, 1096, 188, 6, 70, "Text",
  CellTags->"region-dependent function"]
}, Open  ]],
Cell[31035, 1105, 635, 15, 70, "NumberedEquation"],
Cell[31673, 1122, 196, 8, 70, "BeginEndQuestion"],
Cell[31872, 1132, 676, 25, 70, "BeginEndQuestion"],
Cell[32551, 1159, 327, 12, 70, "BeginEndQuestion"],
Cell[32881, 1173, 619, 20, 70, "BeginEndQuestion",
  CellTags->"discontinuous derivative"],
Cell[33503, 1195, 892, 36, 70, "BeginEndQuestion",
  CellTags->"exact solution"],

Cell[CellGroupData[{
Cell[34420, 1235, 509, 14, 70, "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{"discretizing equations", "inverse problem"}],

Cell[CellGroupData[{
Cell[34954, 1253, 410, 7, 70, "NumberedEquation"],
Cell[35367, 1262, 357, 9, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35761, 1276, 241, 4, 70, "NumberedEquation"],
Cell[36005, 1282, 363, 9, 70, "Warning",
  CellTags->{"equally spaced data points", "trapezoid approximation"}],
Cell[36371, 1293, 806, 27, 70, "Text",
  CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]]
}, Open  ]],
Cell[37204, 1324, 1045, 35, 70, "BeginEndQuestion"],
Cell[38252, 1361, 343, 14, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[38632, 1380, 115, 5, 48, "Section"],
Cell[38750, 1387, 232, 6, 70, "Text",
  CellTags->{"equation of state", "ideal gas"}],

Cell[CellGroupData[{
Cell[39007, 1397, 126, 2, 70, "NumberedEquation"],
Cell[39136, 1401, 305, 7, 70, "Text",
  CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[39478, 1413, 193, 4, 70, "NumberedEquation",
  CellTags->"van der Waals"],
Cell[39674, 1419, 680, 20, 70, "Text"],
Cell[40357, 1441, 826, 29, 70, "Text"]
}, Open  ]],
Cell[41198, 1473, 594, 26, 70, "BeginEndQuestion"],
Cell[41795, 1501, 712, 30, 70, "BeginEndQuestion"],
Cell[42510, 1533, 848, 30, 70, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[43383, 1567, 637, 19, 70, "Text",
  CellGroupingRules->{"SectionGrouping", 45}],

Cell[CellGroupData[{
Cell[44045, 1590, 231, 5, 70, "NumberedEquation",
  CellTags->"equal area"],
Cell[44279, 1597, 1372, 43, 70, "Text",
  CellTags->{"two-phase line", "Maxwell construction"}]
}, Open  ]],
Cell[45666, 1643, 383, 8, 70, "NumberedEquation",
  CellTags->"two-phase"],
Cell[46052, 1653, 1015, 38, 70, "BeginEndQuestion"],
Cell[47070, 1693, 859, 29, 70, "BeginEndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[47978, 1728, 178, 7, 48, "Section",
  Evaluatable->False],
Cell[48159, 1737, 132, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[48316, 1744, 317, 8, 70, "NumberedEquation",
  CellTags->"wave equation"],
Cell[48636, 1754, 206, 6, 70, "Text",
  CellTags->{"boundary condition", "polar coordinates"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[48879, 1765, 184, 3, 70, "NumberedEquation",
  CellTags->"Laplacian"],
Cell[49066, 1770, 471, 19, 70, "Text"],
Cell[49540, 1791, 209, 4, 70, "Input"]
}, Open  ]],
Cell[49764, 1798, 773, 31, 70, "BeginEndQuestion",
  CellTags->"separation of variables"],
Cell[50540, 1831, 993, 33, 70, "BeginEndQuestion"],
Cell[51536, 1866, 644, 22, 70, "BeginEndQuestion"],
Cell[52183, 1890, 442, 18, 70, "BeginEndQuestion"],
Cell[52628, 1910, 1093, 37, 70, "BeginEndQuestion"],
Cell[53724, 1949, 546, 22, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[54307, 1976, 112, 5, 48, "Section"],
Cell[54422, 1983, 139, 6, 70, "Text",
  CellTags->"Pauli spin matrices"],
Cell[54564, 1991, 300, 9, 70, "Input"],
Cell[54867, 2002, 327, 9, 70, "Input"],
Cell[55197, 2013, 303, 9, 70, "Input"],
Cell[55503, 2024, 127, 5, 70, "Text"],
Cell[55633, 2031, 92, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[55750, 2036, 70, 1, 70, "Input"],
Cell[55823, 2039, 228, 7, 70, "Output"]
}, Open  ]],
Cell[56066, 2049, 99, 2, 70, "Text"],
Cell[56168, 2053, 327, 16, 70, "BeginEndQuestion"],
Cell[56498, 2071, 1428, 50, 70, "BeginEndQuestion",
  CellTags->"Levi-Civita tensor"],
Cell[57929, 2123, 758, 30, 70, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[58712, 2157, 2192, 71, 70, "BeginQuestion"],
Cell[60907, 2230, 622, 12, 70, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61566, 2247, 340, 14, 70, "BeginQuestion",
  CellTags->"Dirac gamma matrices"],
Cell[61909, 2263, 786, 15, 70, "NumberedEquation"],
Cell[62698, 2280, 1397, 45, 70, "EndQuestion"]
}, Open  ]],
Cell[64110, 2328, 453, 16, 70, "BeginEndQuestion"],
Cell[64566, 2346, 1785, 61, 70, "BeginEndQuestion"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

