(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18563,        563]
NotebookOptionsPosition[     16151,        483]
NotebookOutlinePosition[     17150,        518]
CellTagsIndexPosition[     17044,        512]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Quiz Generator", "Title",
 CellMargins->{{0, Inherited}, {Inherited, Inherited}},
 CellFrameMargins->{{54, 0}, {12, 12}}],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"Harry", " ", "Calkins"}], 
      RowBox[{"Paul", " ", "Wellin"}]},
     {
      RowBox[{"Wolfram", " ", "Research"}], 
      RowBox[{"Wolfram", " ", "Research"}]},
     {
      RowBox[{
       RowBox[{"harryc", "@", "wolfram"}], ".", "com"}], 
      RowBox[{
       RowBox[{"wellin", "@", "wolfram"}], ".", "com"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[14.]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], TraditionalForm]]],
 "\n"
}], "Subsubtitle",
 FontSize->16],

Cell["\<\
This basic notebook walks through the steps in creating a set of problems \
suitable for a homework assignment or test. The type of problems can be \
modified to create problem sets for any discipline or course.\
\>", "Text"],

Cell["The steps include the following:", "Text"],

Cell["\<\
create two notebooks, one each for the problems and the answers\
\>", "BulletedList"],

Cell["generate problems in factoring and their solutions", "BulletedList"],

Cell["write problems and solutions to notebooks", "BulletedList"],

Cell[TextData[{
 "In this particular notebook we will create a problem set with ten \
trinomials to factor. If you are interested in seeing or modifying any of the \
underlying program code, go ",
 ButtonBox["here",
  BaseStyle->"Hyperlink",
  ButtonData:>"Initializations"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["Create notebooks", "Section"],

Cell["Create the quiz and solution notebooks.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Create notebook templates\>\"", ",", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"nb1", "=", 
      RowBox[{"CreateDocument", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Name____________________________             Hour_______\>\"",
             ",", "\"\<Subsection\>\""}], "]"}], ",", 
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Solutions to Factor Problems.\>\"", ",", 
            "\"\<Subsubsection\>\""}], "]"}]}], "}"}], ",", 
        RowBox[{"ShowCellLabel", "\[Rule]", " ", "False"}], ",", 
        RowBox[{"WindowTitle", "\[Rule]", " ", "\"\<Quiz Solutions\>\""}]}], 
       "]"}]}], ";", "\n", 
     RowBox[{"SelectionMove", "[", 
      RowBox[{"nb1", ",", "After", ",", "Notebook"}], "]"}], ";", "\n", 
     RowBox[{"nb2", "=", 
      RowBox[{"CreateDocument", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Name____________________________             Hour_______\>\"",
             ",", "\"\<Subsection\>\""}], "]"}], ",", 
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Factor the following expressions.\>\"", ",", 
            "\"\<Subsubsection\>\""}], "]"}]}], "}"}], ",", 
        RowBox[{"ShowCellLabel", "\[Rule]", " ", "False"}], ",", 
        RowBox[{"WindowTitle", "\[Rule]", " ", "\"\<Quiz Problems\>\""}]}], 
       "]"}]}], ";", "\n", 
     RowBox[{"SelectionMove", "[", 
      RowBox[{"nb2", ",", "After", ",", "Notebook"}], "]"}], ";"}], ")"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.387096497579331*^9, 3.387096511704193*^9}}],

Cell[BoxData[
 ButtonBox["\<\"Create notebook templates\"\>",
  Appearance->Automatic,
  ButtonFrame->"DialogBox",
  ButtonFunction:>($CellContext`nb1 = CreateDocument[{
       TextCell[
       "Name____________________________             Hour_______", 
        "Subsection"], 
       TextCell["Solutions to Factor Problems.", "Subsubsection"]}, 
      ShowCellLabel -> False, WindowTitle -> "Quiz Solutions"]; 
   SelectionMove[$CellContext`nb1, After, Notebook]; $CellContext`nb2 = 
    CreateDocument[{
       TextCell[
       "Name____________________________             Hour_______", 
        "Subsection"], 
       TextCell["Factor the following expressions.", "Subsubsection"]}, 
      ShowCellLabel -> False, WindowTitle -> "Quiz Problems"]; 
   SelectionMove[$CellContext`nb2, After, Notebook]; Null),
  Evaluator->Automatic,
  Method->"Preemptive"]], "Output",
 CellChangeTimes->{3.387096525238284*^9}]
}, {2}]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate problems and answers", "Section"],

Cell[TextData[{
 "This function is used to generate the source for ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " trinomials to factor. The first argument to the function is a list of \
values to use for the parameters and the second argument is the number of \
problems to generate. Evaluating ",
 StyleBox["MakeProblems", "MR"],
 " with no arguments will generate 6 problems which factor to (",
 StyleBox["x-a",
  FontSlant->"Italic"],
 ") (",
 StyleBox["x - b",
  FontSlant->"Italic"],
 ") where ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " are taken from  the list {-5, -4, -3, -2, -1, 1, 2, 3, 4, 5}."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeProblems", "[", 
   RowBox[{"params_List", ",", "vars_List", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tempvar", "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tempvar", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"vars", ",", "1"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"var", "-", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{"params", ",", "1"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"var", "-", " ", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{"params", ",", "1"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "/.", 
         RowBox[{"var", "\[RuleDelayed]", "tempvar"}]}]}], ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.382881293049057*^9, 3.382881301618705*^9}, {
   3.382881345697707*^9, 3.3828814412072287`*^9}, {3.38288157452843*^9, 
   3.382881619350528*^9}, {3.38288189027085*^9, 3.382881896659444*^9}, 
   3.383293129113566*^9}],

Cell["\<\
This creates the source for 8 problems with parameters chosen from {-9, -8, \
-7, -6, -5, -4, -3, -2, -1, 1, 2, 3, 4, 5, 
 6, 7, 8, 9}.\
\>", "MathCaption",
 CellChangeTimes->{{3.382896319560614*^9, 3.382896377062849*^9}}],

Cell[BoxData[
 RowBox[{"MakeProblems", "[", 
  RowBox[{
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9"}], "]"}], ",", "0"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "8"}], "]"}]], "Input",
 CellChangeTimes->{
  3.3828807808443937`*^9, {3.3828814545766478`*^9, 3.382881496218342*^9}, {
   3.382896434704235*^9, 3.3828964386371937`*^9}, {3.383293136633893*^9, 
   3.383293143846451*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Write problems and answers to notebooks", "Section"],

Cell["\<\
Evaluate the following cell to define the source for the problems.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"MakeProblems", "[", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{
        RowBox[{"-", "9"}], ",", "9"}], "]"}], ",", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "r", ",", "s"}], "}"}], ",", "8"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.383293155920326*^9, 3.383293162965126*^9}}],

Cell[TextData[{
 "\nPress the ",
 StyleBox["Make Problems", "SR"],
 " button below to generate the quiz and solutions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Make Problems\>\"", ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Unevaluated", "[", "sols", "]"}], "=!=", "sols"}], ",", 
     RowBox[{
      RowBox[{"NotebookLocate", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EvaluationNotebook", "[", "]"}], ",", "\"\<MakeProbs\>\""}],
         "}"}], "]"}], ";", 
      RowBox[{"FrontEndExecute", "[", 
       RowBox[{"{", 
        RowBox[{"FrontEndToken", "[", 
         RowBox[{
          RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
          "\"\<EvaluateCells\>\""}], "]"}], "}"}], "]"}]}], ",", 
     RowBox[{"CreateDocument", "[", 
      RowBox[{
       RowBox[{"Cell", "[", 
        RowBox[{
        "\"\<You must first define the source problems with \
MakeProblems.\>\"", ",", "\"\<Text\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "18", 
         ",", 
         RowBox[{"FontColor", "\[Rule]", " ", "Red"}]}], "]"}], ",", 
       RowBox[{"WindowSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"450", ",", "100"}], "}"}]}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 ButtonBox["\<\"Make Problems\"\>",
  Appearance->Automatic,
  ButtonFrame->"DialogBox",
  ButtonFunction:>If[
   Unevaluated[$CellContext`sols] =!= $CellContext`sols, NotebookLocate[{
       EvaluationNotebook[], "MakeProbs"}]; FrontEndExecute[{
       FrontEndToken[
        FrontEnd`EvaluationNotebook[], "EvaluateCells"]}], 
    CreateDocument[
     Cell[
     "You must first define the source problems with MakeProblems.", "Text", 
      FontFamily -> "Helvetica", 18, FontColor -> Red], 
     WindowSize -> {450, 100}]],
  Evaluator->Automatic,
  Method->"Preemptive"]], "Output"]
}, {2}]],

Cell["\<\
You can now save the notebooks in the usual way. If you wish to give the \
notebooks different names use SaveAs from the file menu.\
\>", "Text",
 CellChangeTimes->{{3.382895946814027*^9, 3.382896037014525*^9}}],

Cell[TextData[{
 "Problems? Have you made the notebooks? If not, go back to the Create \
notebooks section above and click the ",
 StyleBox["Create notebooks template", "SR"],
 " button."
}], "MathCaption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initializations", "Section",
 FontColor->GrayLevel[0.666667],
 CellTags->"Initializations"],

Cell[TextData[{
 "The following cells are intended to fill the quiz and solution notebooks \
and should not be evaluated directly. They are used by the ",
 StyleBox["Make Problems", "SR"],
 " button for filling the notebook. Evaluating these cells out of order can \
lead to undesirable results."
}], "Text",
 CellTags->"Initializations"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringForm", "[", 
          RowBox[{"\"\<``)  ``\>\"", ",", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"TraditionalForm", "[", 
            RowBox[{"Expand", "[", "#1", "]"}], "]"}]}], "]"}], "&"}], ",", 
        "sols"}], "]"}], ",", "2"}], "]"}], ",", 
    RowBox[{"ItemStyle", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", " ", "14"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSlant", "\[Rule]", " ", "\"\<Italic\>\""}]}], "}"}]}], 
    ",", 
    RowBox[{"Spacings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"15", ",", "10"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Previous", ",", "Cell"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Copy\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Clear\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{"nb2", ",", "\"\<Paste\>\""}], "]"}], "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Next", ",", "Cell"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<EvaluateCells\>\""}], "]"}], "}"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.382879892717881*^9, 3.382879925910349*^9}, {
   3.382879978683601*^9, 3.382879998744322*^9}, 3.3828800562830477`*^9, 
   3.382880494369796*^9, {3.3828808817615147`*^9, 3.382880908118393*^9}, {
   3.382881010949081*^9, 3.3828810288528023`*^9}, {3.382897329122202*^9, 
   3.382897360543453*^9}},
 CellTags->{"MakeProbs", "Initializations"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringForm", "[", 
          RowBox[{"\"\<``)  ``\>\"", ",", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"TraditionalForm", "[", "#1", "]"}]}], "]"}], "&"}], ",", 
        "sols"}], "]"}], ",", "2"}], "]"}], ",", 
    RowBox[{"ItemStyle", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", " ", "14"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSlant", "\[Rule]", " ", "\"\<Italic\>\""}]}], "}"}]}], 
    ",", 
    RowBox[{"Spacings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"15", ",", "10"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Previous", ",", "Cell", 
    ",", "1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Copy\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Clear\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{"nb1", ",", "\"\<Paste\>\""}], "]"}], "}"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.3828803191440496`*^9, 3.382880373493977*^9}, 
   3.3828805094711227`*^9, {3.382897414162738*^9, 3.382897436394994*^9}},
 CellTags->"Initializations"]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Brackets",
WindowSize->{809, 688},
WindowMargins->{{196, Automatic}, {Automatic, 10}},
ShowSelection->True,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (April 25, 2007)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "WEGSeminar.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initializations"->{
  Cell[11118, 342, 97, 2, 33, "Section",
   CellTags->"Initializations"],
  Cell[11218, 346, 338, 7, 61, "Text",
   CellTags->"Initializations"],
  Cell[11559, 355, 2606, 69, 222, "Input",
   CellTags->{"MakeProbs", "Initializations"}],
  Cell[14168, 426, 1955, 53, 162, "Input",
   CellTags->"Initializations"]},
 "MakeProbs"->{
  Cell[11559, 355, 2606, 69, 222, "Input",
   CellTags->{"MakeProbs", "Initializations"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initializations", 16599, 497},
 {"MakeProbs", 16929, 506}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 127, 2, 54, "Title"],
Cell[CellGroupData[{
Cell[720, 27, 852, 27, 80, "Subsubtitle"],
Cell[1575, 56, 235, 4, 40, "Text"],
Cell[1813, 62, 48, 0, 22, "Text"],
Cell[1864, 64, 95, 2, 22, "BulletedList"],
Cell[1962, 68, 74, 0, 22, "BulletedList"],
Cell[2039, 70, 65, 0, 22, "BulletedList"],
Cell[2107, 72, 292, 8, 40, "Text"],
Cell[CellGroupData[{
Cell[2424, 84, 35, 0, 59, "Section"],
Cell[2462, 86, 62, 0, 38, "MathCaption"],
Cell[CellGroupData[{
Cell[2549, 90, 1746, 42, 219, "Input"],
Cell[4298, 134, 914, 20, 57, "Output"]
}, {2}]]
}, Closed]],
Cell[CellGroupData[{
Cell[5258, 160, 48, 0, 33, "Section"],
Cell[5309, 162, 676, 21, 80, "Text"],
Cell[5988, 185, 1368, 35, 142, "Input",
 InitializationCell->True],
Cell[7359, 222, 232, 5, 66, "MathCaption"],
Cell[7594, 229, 503, 13, 42, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8134, 247, 58, 0, 33, "Section"],
Cell[8195, 249, 90, 2, 23, "Text"],
Cell[8288, 253, 420, 12, 42, "Input"],
Cell[8711, 267, 131, 4, 42, "Text"],
Cell[CellGroupData[{
Cell[8867, 275, 1168, 31, 122, "Input"],
Cell[10038, 308, 601, 15, 49, "Output"]
}, {2}]],
Cell[10651, 326, 221, 4, 42, "Text"],
Cell[10875, 332, 206, 5, 58, "MathCaption"]
}, Closed]],
Cell[CellGroupData[{
Cell[11118, 342, 97, 2, 33, "Section",
 CellTags->"Initializations"],
Cell[11218, 346, 338, 7, 61, "Text",
 CellTags->"Initializations"],
Cell[11559, 355, 2606, 69, 222, "Input",
 CellTags->{"MakeProbs", "Initializations"}],
Cell[14168, 426, 1955, 53, 162, "Input",
 CellTags->"Initializations"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
